@@ -36,31 +36,16 @@ DialogPreferences::DialogPreferences(	BaseObjectType* cobject,
 	Lifeobase::builder->get_widget( "hbox_max_idle_time", m_hbox_max_idle_time );
 	Lifeobase::builder->get_widget( "checkbutton_autologout", m_chkbtn_autologout );
 	Lifeobase::builder->get_widget( "spinbutton_max_idle_time", m_spinbutton_max_idle_time );
-	Lifeobase::builder->get_widget( "checkbutton_bg_image", m_chkbtn_bg_image );
-	Lifeobase::builder->get_widget( "filebutton_bg_image", m_filebutton_bg_image );
 	Lifeobase::builder->get_widget( "chkbtn_formatting_toolbar", m_chkbtn_formatting_toolbar );
 
 	m_chkbtn_autologout->set_active( Lifeobase::m_settings.autologout );
 	m_hbox_max_idle_time->set_sensitive( Lifeobase::m_settings.autologout );
 	m_spinbutton_max_idle_time->set_value( Lifeobase::m_settings.idletime );
 
-	if( Lifeobase::m_settings.background == "none" )
-	{
-		m_chkbtn_bg_image->set_active( false );
-		m_filebutton_bg_image->set_sensitive( false );
-	}
-	else
-	{
-		m_chkbtn_bg_image->set_active( true );
-		m_filebutton_bg_image->set_filename( Lifeobase::m_settings.background );
-	}
-
 	m_chkbtn_formatting_toolbar->set_active( Lifeobase::m_settings.show_formatting_toolbar );
 
 	m_chkbtn_autologout->signal_toggled().connect(
 			sigc::mem_fun( *this, &DialogPreferences::handle_chkbtn_autologout_toggled ) );
-	m_chkbtn_bg_image->signal_toggled().connect(
-			sigc::mem_fun( *this, &DialogPreferences::handle_chkbtn_autologout_toggled ) );
 
 	m_chkbtn_formatting_toolbar->signal_toggled().connect(
 			sigc::mem_fun( *this, &DialogPreferences::handle_chkbtn_ftoolbar_toggled ) );
@@ -73,7 +58,6 @@ void
 DialogPreferences::handle_chkbtn_autologout_toggled( void )
 {
 	m_hbox_max_idle_time->set_sensitive( m_chkbtn_autologout->get_active() );
-	m_filebutton_bg_image->set_sensitive( m_chkbtn_bg_image->get_active() );
 }
 
 void
@@ -90,29 +74,6 @@ DialogPreferences::handle_response( int )
 	// APPLY CHANGES
 	Lifeobase::m_settings.autologout = m_chkbtn_autologout->get_active();
 	Lifeobase::m_settings.idletime = m_spinbutton_max_idle_time->get_value_as_int();
-	if( m_chkbtn_bg_image->get_active() )
-	{
-		if( Lifeobase::m_settings.background != m_filebutton_bg_image->get_filename() )
-		{
-			Lifeobase::m_settings.background = m_filebutton_bg_image->get_filename();
-			try
-			{
-				Lifeobase::pixbuf_background =
-						Gdk::Pixbuf::create_from_file( Lifeobase::m_settings.background );
-			}
-			catch( Glib::Error &ex )
-			{
-				print_error( ex.what() );
-				Lifeobase::m_settings.background = "none";
-				Lifeobase::pixbuf_background.clear();
-			}
-		}
-	}
-	else
-	{
-		Lifeobase::m_settings.background = "none";
-		Lifeobase::pixbuf_background.clear();
-	}
 }
 
 void
