@@ -40,8 +40,8 @@ using namespace LIFEO;
 
 
 // STATIC MEMBERS
-Diary				*Diary::d;
-Diary::Shower		*Diary::shower;
+Diary                   *Diary::d;
+ElementShower< Diary >  *Diary::shower( NULL );
 
 static const char	DEFAULT_CHAPTER_CTG_NAME[]	= N_( "Default" );
 
@@ -65,7 +65,7 @@ Glib::ustring
 get_db_line_name( const Glib::ustring &line )
 {
 	Glib::ustring::size_type begin( line.find( '\t' ) );
-	if( begin == Glib::ustring::npos )
+	if( begin == std::string::npos )
 		begin = 2;
 	else
 		begin++;
@@ -73,14 +73,15 @@ get_db_line_name( const Glib::ustring &line )
 	return( line.substr( begin ) );
 }
 
-// DIARY =======================================================================
+// DIARY ===========================================================================================
 Diary::Diary( const std::string &path )
-:	DiaryElement( this ), m_path( path ), m_passphrase( "" ),
-	m_ptr2chapter_ctg_cur( NULL ), m_topics( this, "topics" ),
-	m_default_theme( ThemeSystem::get() ), m_startup_elem( HOME_CURRENT_ELEM ),
-	m_last_elem( DEID_MIN ),
-	m_option_spellcheck( false ), m_option_sorting_criteria( SC_DATE ), m_read_version( 0 ),
-	m_filter_text( "" ), m_filter_tag( NULL ), m_filtering_status( FS_CLEAR )
+:   DiaryElement( this ), m_path( path ), m_passphrase( "" ),
+    m_ptr2chapter_ctg_cur( NULL ), m_topics( this, "topics" ),
+    m_default_theme( ThemeSystem::get() ), m_startup_elem( HOME_CURRENT_ELEM ),
+    m_last_elem( DEID_MIN ),
+    m_option_spellcheck( false ), m_option_sorting_criteria( SC_DATE ), m_read_version( 0 ),
+    m_filter_text( "" ), m_filter_tag( NULL ), m_filter_date_begin( 0 ),
+    m_filter_date_end( Date::DATE_MAX ), m_filtering_status( FS_CLEAR )
 {
 	// "touch" new lock:
 	std::string path_lock = m_path + LOCK_SUFFIX;
@@ -94,12 +95,13 @@ Diary::Diary( const std::string &path )
 
 // derived classes should use this
 Diary::Diary( void )
-:	DiaryElement( this ), m_path( "" ), m_passphrase( "" ),
-	m_ptr2chapter_ctg_cur( NULL ), m_topics( this, "topics" ),
-	m_default_theme( ThemeSystem::get() ), m_startup_elem( HOME_CURRENT_ELEM ),
-	m_last_elem( DEID_MIN ),
-	m_option_spellcheck( false ), m_option_sorting_criteria( SC_DATE ), m_read_version( 0 ),
-	m_filter_text( "" ), m_filter_tag( NULL ), m_filtering_status( FS_CLEAR )
+:   DiaryElement( this ), m_path( "" ), m_passphrase( "" ),
+    m_ptr2chapter_ctg_cur( NULL ), m_topics( this, "topics" ),
+    m_default_theme( ThemeSystem::get() ), m_startup_elem( HOME_CURRENT_ELEM ),
+    m_last_elem( DEID_MIN ),
+    m_option_spellcheck( false ), m_option_sorting_criteria( SC_DATE ), m_read_version( 0 ),
+    m_filter_text( "" ), m_filter_tag( NULL ), m_filter_date_begin( 0 ),
+    m_filter_date_end( Date::DATE_MAX ), m_filtering_status( FS_CLEAR )
 {
 	// add system theme to the pool where it will remain till the diary is destroyed:
 	m_themes.insert( PoolThemes::value_type( m_default_theme->get_name(), m_default_theme ) );
@@ -153,7 +155,9 @@ Diary::clear( void )
 
 	m_filter_text.clear();
 	m_filter_tag = NULL;
-	m_filtering_status = FS_CLEAR;
+    m_filter_date_begin = 0;
+    m_filter_date_end = Date::DATE_MAX;
+    m_filtering_status = FS_CLEAR;
 
 	// NOTE: only reset body options here:
 	m_option_spellcheck = true;
@@ -752,7 +756,7 @@ Diary::parse_db_body_text_56( std::stringstream &stream )
 			case 'A':	// date
 			{	// FIXME: temporary (for compatibility)
 				Date::date_t date_new = LIFEO::convert_string( line.substr( 2 ) );
-				if( date_new == ( ( date.m_date >> 10 ) + 1 ) )
+				if( date_new == ( date.m_date >> 10 ) )
 					date.m_date++;
 				else
 					date.m_date = ( date_new << 10 ) + 1;
@@ -832,52 +836,47 @@ Diary::parse_db_body_text_56( std::stringstream &stream )
 LIFEO::Result
 Diary::write( void )
 {
+    m_flag_only_save_filtered = false;
+
 	std::string path_old( m_path + ".~previousversion~" );
 
 	if( Glib::file_test( m_path, Glib::FILE_TEST_EXISTS ) )
 		rename( m_path.c_str(), path_old.c_str() );
 
-	Result result;
-	if( m_passphrase.empty() )
-		result = write_plain( m_path );
-	else
-		result = write_encrypted( m_path );
+	Result result( write( m_path ) );
 
 // DAILY BACKUP SAVES
 #ifdef LIFEOGRAPH_DEBUG_BUILD
-	if( m_entries.empty() )
-		return result;
+    if( ! m_entries.empty() )
+    {
+        Glib::Date gdate;
+        gdate.set_time_current();
+        Date date( gdate.get_year(), gdate.get_month(), gdate.get_day() );
 
-	Result result_daily;
-	std::string path_daily( m_path + "." + m_entries.begin()->second->get_date().format_string() );
+        std::string path_daily( m_path + "." + date.format_string() );
 
-	if( m_passphrase.empty() )
-		result_daily = write_plain( path_daily );
-	else
-		result_daily = write_encrypted( path_daily );
-
-	if( result_daily == SUCCESS )
-		PRINT_DEBUG( "daily backup has been written successfully" );
+        if( write( path_daily ) == SUCCESS )
+            print_info( "daily backup has been written successfully" );
+    }
 #endif
 
 	return result;
 }
 
 LIFEO::Result
-Diary::write( const std::string& path )
+Diary::write( const std::string &path )
 {
-	Result result;
-	if( m_passphrase.empty() )
-		result = write_plain( path );
-	else
-		result = write_encrypted( path );
-
-	return result;
+    if( m_passphrase.empty() )
+        return write_plain( path );
+    else
+        return write_encrypted( path );
 }
 
 LIFEO::Result
-Diary::write_copy( const std::string &path, const std::string &passphrase )
+Diary::write_copy( const std::string &path, const std::string &passphrase, bool flag_filtered )
 {
+    m_flag_only_save_filtered = flag_filtered;
+
 	Result result;
 
 	if( passphrase.empty() )
@@ -894,7 +893,7 @@ Diary::write_copy( const std::string &path, const std::string &passphrase )
 }
 
 LIFEO::Result
-Diary::write_txt( const std::string &path )
+Diary::write_txt( const std::string &path, bool flag_filtered )
 {
 	std::ofstream file( path.c_str(), std::ios::out | std::ios::trunc );
 	if( ! file.is_open() )
@@ -903,45 +902,80 @@ Diary::write_txt( const std::string &path )
 		return LIFEO::COULD_NOT_START;
 	}
 
+    const CategoryChapters  *chapters( Diary::d->get_current_chapter_ctg() );
+    CategoryChapters::const_reverse_iterator
+                            iter_chapter( chapters->rbegin() );
+    Chapter                 *chapter( NULL );
+    bool                    flag_chapter_round( true );    // chapter or topic round
+    const std::string       separator( "---------------------------------------------\n");
+
 	// ENTRIES
-	for(	Entryiter itr_entry = m_entries.begin();
-			itr_entry != m_entries.end();
-			itr_entry++ )
+    for( EntryIterReverse itr_entry = m_entries.rbegin();
+         itr_entry != m_entries.rend();
+         ++itr_entry )
 	{
-		Entry *entry = itr_entry->second;
-		// purge empty entries:
-		if( entry->m_text.size() < 1 ) continue;
+        Entry *entry( itr_entry->second );
 
-		file << ( "---------------------------------------------\n\n\n" );
+        for( ; ; ++iter_chapter)
+        {
+            if( iter_chapter == chapters->rend() )
+            {
+                if( flag_chapter_round )
+                {
+                    chapters = Diary::d->get_topics();
+                    iter_chapter = chapters->rbegin();
+                    flag_chapter_round = false;
+                    continue;
+                }
+                else
+                    break;
+            }
 
-		// DATE AND FAVOREDNESS
-		if( entry->is_favored() )
-			file << "*** ";
-		file << entry->get_date().format_string();
-		if( entry->is_favored() )
-			file << " ***";
+            chapter = iter_chapter->second;
 
-		// TAGS
-		const Tagset &tagset = entry->get_tags();
-		for(	Tagset::const_iterator itr_tags = tagset.begin();
-				itr_tags != tagset.end();
-				++itr_tags )
-		{
-			if( itr_tags == tagset.begin() )
-				file << "\n>>> "; // FIXME: use a more meaningful sign
-			else
-				file << ", ";
+            if( chapter->is_initialized() )
+            {
+                if( entry->get_date() >= chapter->get_date() )
+                    file << "\n\n" << separator << chapter->get_date().format_string() <<
+                    " - " << chapter->get_name() << "\n";
+                else
+                    break;
+            }
+        }
 
-			file << ( *itr_tags )->get_name();
-		}
+        // purge empty entries:
+        if( ( entry->m_text.size() < 1 && entry->get_tags().size() < 1 ) ||
+            ( entry->get_filtered_out() && flag_filtered ) )
+            continue;
 
-		// CONTENT
-		file << "\n\n" << entry->get_text();
+        file << separator;
 
-		file << "\n\n\n";
-	}
-	file.close();
-	return SUCCESS;
+        // DATE AND FAVOREDNESS
+        file << entry->get_date().format_string();
+        if( entry->is_favored() )
+            file << "  [" << _( "FAVORITE" ) << "]";
+
+        // CONTENT
+        file << "\n" << entry->get_text();
+
+        // TAGS
+        const Tagset &tagset = entry->get_tags();
+        for( Tagset::const_iterator itr_tags = tagset.begin();
+             itr_tags != tagset.end();
+             ++itr_tags )
+        {
+            if( itr_tags == tagset.begin() )
+                file << "\n\n" << _( "TAGS" ) << ": ";
+            else
+                file << ", ";
+
+            file << ( *itr_tags )->get_name();
+        }
+
+        file << "\n\n\n";
+    }
+    file.close();
+    return SUCCESS;
 }
 
 LIFEO::Result
@@ -1122,8 +1156,12 @@ Diary::create_db_body_text( std::stringstream &output )
 	{
 		Entry *entry = ( *iter_entry ).second;
 
-		// PURGE EMPTY ENTRIES IF THEY HAVE NO TAGS EITHER
+		// purge empty entries:
 		if( entry->m_text.size() < 1 && entry->m_tags.empty() ) continue;
+		// optionally only save filtered entries:
+		else
+		if( entry->get_filtered_out() && m_flag_only_save_filtered ) continue;
+
 
 		// ENTRY DATE
 		output << "ID" << entry->get_id() << "\nE" <<
@@ -1235,7 +1273,7 @@ Diary::get_prev_session_elem( void )
 	return get_element( m_last_elem );
 }
 
-// ENTRIES =====================================================================
+// ENTRIES =========================================================================================
 Entry*
 Diary::add_today( void )
 {
@@ -1248,16 +1286,13 @@ Diary::add_today( void )
 }
 
 Entry*
-Diary::get_entry( const Date &date )
+Diary::get_entry( const Date::date_t date )
 {
-	for( Entryiter iter = m_entries.find( date.m_date ); iter != m_entries.end(); ++iter )
-	{
-		if( iter->second->get_date().get_pure() != date.get_pure() )
-			break;
-		else
-		if( iter->second->get_filtered_out() == false )
-			return iter->second;
-	}
+    Entryiter iter( m_entries.find( date ) );
+    if( iter != m_entries.end() )
+        if( iter->second->get_filtered_out() == false )
+            return iter->second;
+
 	return NULL;
 }
 
@@ -1266,9 +1301,9 @@ Diary::get_entry_today( void )
 {
 	time_t t = time( NULL );
 	struct tm *ti = localtime( &t );
-	Date date( ti->tm_year + 1900, ti->tm_mon + 1, ti->tm_mday );
+	Date date( ti->tm_year + 1900, ti->tm_mon + 1, ti->tm_mday, 1 );
 
-	return get_entry( date );
+	return get_entry( date.m_date );
 }
 
 Entryvector*
@@ -1276,7 +1311,7 @@ Diary::get_entries( Date::date_t date )	// takes pure date
 {
 	Entryvector *entries = new Entryvector;
 
-	Entryiter iter = m_entries.find( date );
+	Entryiter iter = m_entries.find( date + 1 );
 	if( iter == m_entries.end() )
 		return entries;	// return empty vector
 
@@ -1299,7 +1334,7 @@ bool
 Diary::get_day_has_multiple_entries( const Date &date_impure )
 {
 	Date::date_t date = date_impure.get_pure();
-	Entryiter iter = m_entries.find( date );
+	Entryiter iter = m_entries.find( date + 1 );
 	if( iter == m_entries.end() || iter == m_entries.begin() )
 		return false;
 
@@ -1320,48 +1355,19 @@ Diary::get_day_has_multiple_entries( const Date &date_impure )
 }
 
 Entry*
-Diary::get_entry_nextinday( const Date &date )
+Diary::get_entry_next_in_day( const Date &date )
 {
-	Entryiter entry_1st = m_entries.find( date.m_date + 1 );
-	if( entry_1st != m_entries.end() )
-		return entry_1st->second;
-	else
-	if( date.get_order() > 0 )
-	{
-		entry_1st = m_entries.find( date.get_pure() );
-		if( entry_1st != m_entries.end() )
-			return entry_1st->second;
-		else
-			return NULL;
-	}
-	else
-		return NULL;
-	/* TODO MAP
-	Entryiter	iter_last			= m_entries.end();
-	Entryiter	iter_firstinday		= iter_last;
-	bool		flag_found			= false;
-
-	for( Entryiter iter = m_entries.begin(); iter != iter_last; ++iter )
-	{
-		if( ( *iter )->get_date() == date )
-		{
-			if( iter_firstinday == iter_last )
-				iter_firstinday = iter;
-			if( *iter == entry )
-				flag_found = true;
-			else
-			if( flag_found )
-				return( *iter );
-		}
-		else
-		if( iter_firstinday != iter_last )
-			break;
-	}
-
-	if( iter_firstinday != iter_last && *iter_firstinday != entry )
-		return( * iter_firstinday );
-	else
-		return NULL;*/
+    Entryiter entry_1st( m_entries.find( date.get_pure() + 1 ) );
+    if( entry_1st == m_entries.end() )
+        return NULL;
+    Entryiter entry_next( m_entries.find( date.m_date + 1 ) );
+    if( entry_next != m_entries.end() )
+        return entry_next->second->get_filtered_out() ? NULL : entry_next->second;
+    else
+    if( date.get_order() > 1 )
+        return entry_1st->second->get_filtered_out() ? NULL : entry_1st->second;
+    else
+        return NULL;
 }
 
 Entry*
@@ -1497,7 +1503,7 @@ Diary::set_entry_date( Entry *entry, const Date &date )
 	m_entries[ date.m_date ] = entry;
 }
 
-// FILTERING ===================================================================
+// FILTERING =======================================================================================
 void
 Diary::set_filter_text( const Glib::ustring &filter )
 {
@@ -1541,6 +1547,40 @@ Diary::toggle_filter_favorites( void )
 	m_filtering_status |= FS_NEW;
 }
 
+void
+Diary::clear_filter_date( void )
+{
+    m_filter_date_begin = 0;
+    m_filter_date_end = Date::DATE_MAX;
+    if( m_filtering_status & FS_FILTER_DATE )
+        m_filtering_status -= FS_FILTER_DATE;
+
+    m_filtering_status |= FS_NEW;
+}
+
+void
+Diary::set_filter_date_begin( Date::date_t d )
+{
+    m_filtering_status |= FS_FILTER_DATE;
+    m_filtering_status |= FS_NEW;
+    m_filter_date_begin = d;
+}
+
+void
+Diary::set_filter_date_end( Date::date_t d )
+{
+    m_filtering_status |= FS_FILTER_DATE;
+    m_filtering_status |= FS_NEW;
+    m_filter_date_end = d;
+}
+
+// called when some entries are filtered out individually irrespective of filtering criteria
+void
+Diary::activate_individual_filter( void )
+{
+    m_filtering_status |= FS_FILTER_DATE;
+}
+
 int
 Diary::replace_text( const Glib::ustring &newtext )
 {
@@ -1575,7 +1615,7 @@ Diary::replace_text( const Glib::ustring &newtext )
 	return 0;	// reserved
 }
 
-// TAGS ========================================================================
+// TAGS ============================================================================================
 Tag*
 Diary::create_tag( const Glib::ustring &name, CategoryTags *category )
 {
@@ -1655,7 +1695,7 @@ Diary::dismiss_tag_ctg( CategoryTags *category )
 	delete category;
 }
 
-// CHAPTERS ====================================================================
+// CHAPTERS ========================================================================================
 CategoryChapters*
 Diary::create_chapter_ctg( void )
 {
@@ -1800,98 +1840,6 @@ Diary::add_topic( const Glib::ustring &name )
 	return c;
 }
 
-/*
-void
-Diary::place_entry_in_chapters( DiaryElement *entry )
-{
-	
-	for( PoolCategoriesChapters::const_iterator iter_set = m_chapter_categories.begin();
-		 iter_set != m_chapter_categories.end();
-		 ++iter_set )
-	{
-		for( CategoryChapters::const_iterator iter_chapter = iter_set->second->begin();
-			 iter_chapter != iter_set->second->end();
-			 ++iter_chapter )
-		{
-			if( ( * iter_chapter )->is_initialized() )
-			{
-				if( entry->get_date() >= ( * iter_chapter )->get_date() )
-				{
-					( * iter_chapter )->get_items()->insert( entry );
-					break;
-				}
-			}
-		}
-	}
-}*/
-
-/*void
-Diary::update_entries_in_chapters( CategoryChapters *set )
-{
-	// if set==NULL update current
-	if( set == NULL )
-	{
-		if( m_ptr2chapter_ctg_cur != NULL )
-			set = m_ptr2chapter_ctg_cur;
-		else
-			return;
-	}
-	Entryiter	iter_last = m_entries.end();
-
-	// CLEAR ALL CHAPTERS
-	for( CategoryChapters::const_iterator iter_chapter = set->begin();
-		 iter_chapter != set->end();
-		 ++iter_chapter )
-	{
-		( * iter_chapter )->clear();
-	}
-
-	// INSERT ENTRIES AGAIN
-	for(	Entryiter iter_entry = m_entries.begin();
-			iter_entry != iter_last;
-			++iter_entry )
-	{
-		// TODO: efficiency: do not start form the beginning each time:
-		for(	CategoryChapters::const_iterator iter_chapter = set->begin();
-				iter_chapter != set->end();
-				++iter_chapter )
-		{
-			if( ( * iter_chapter )->is_initialized() )
-			{
-				if( iter_entry->second->get_date().get_pure()
-					>= ( * iter_chapter )->get_date().m_date )
-				{
-					DiaryElement *elem( iter_entry->second );
-					( * iter_chapter )->get_items()->insert( elem );
-					break;
-				}
-			}
-		}
-	}
-}
-
-void
-Diary::remove_entry_from_chapters( DiaryElement *entry )
-{
-	for( PoolCategoriesChapters::const_iterator iter_set = m_chapter_categories.begin();
-		 iter_set != m_chapter_categories.end();
-		 ++iter_set  )
-	{
-		for( CategoryChapters::const_iterator iter_chapter = iter_set->second->begin();
-			 iter_chapter != iter_set->second->end();
-			 ++iter_chapter )
-		{
-			SetDiaryElements *elements( ( * iter_chapter )->get_items() );
-			if( elements->find( entry ) != elements->end() )
-			{
-				PRINT_DEBUG( "element erased" );
-				elements->erase( entry );
-				break;
-			}
-		}
-	}
-}*/
-
 Date
 Diary::get_free_chapter_order_temporal( void )
 {
@@ -1923,7 +1871,7 @@ Diary::make_free_entry_order( Date &date )
 	return true;	// reserved for bounds checking
 }
 
-// THEMES ======================================================================
+// THEMES ==========================================================================================
 Theme*
 Diary::create_theme( const Glib::ustring& name )
 {
@@ -1936,7 +1884,7 @@ Diary::create_theme( const Glib::ustring& name )
 }
 
 Theme*
-Diary::duplicate_theme( const Theme &theme )
+Diary::duplicate_theme( const Theme *theme )
 {
 	Glib::ustring name = create_unique_name_for_map( m_themes, _( "New theme" ) );
 	Theme *new_theme = new Theme( theme );	// duplication
@@ -1970,7 +1918,7 @@ Diary::show( void )
 		shower->show( *this );
 }
 
-// IMPORTING ===================================================================
+// IMPORTING =======================================================================================
 bool
 Diary::import_tag( Tag *tag )
 {
@@ -2003,6 +1951,14 @@ Diary::import_entryset( const PoolEntries &set,
 		while( m_entries.find( entry_new->m_date.m_date ) != m_entries.end() )
 			entry_new->m_date.m_date++;
 
+        // try to preserve the theme:
+        if( entry_ext->get_theme_is_set() )
+        {
+            PoolThemes::iterator iter( m_themes.find( entry_ext->get_theme()->get_name() ) );
+            if( iter != m_themes.end() )
+                entry_new->set_theme( iter->second );
+        }
+
 		// copy dates:
 		entry_new->m_date_created = entry_ext->m_date_created;
 		entry_new->m_date_changed = entry_ext->m_date_changed;
@@ -2027,3 +1983,23 @@ Diary::import_entryset( const PoolEntries &set,
 
 	return true;
 }
+
+bool
+Diary::import_themes( const PoolThemes &themes )
+{
+    for( PoolThemes::const_iterator iter = themes.begin();
+         iter != themes.end();
+         ++iter )
+    {
+        Theme *theme( iter->second );
+        if( theme->is_system() )
+            continue;
+
+        Glib::ustring name( create_unique_name_for_map( m_themes, theme->m_name ) );
+        Theme *new_theme( new Theme( theme ) ); // theme is duplicated
+        new_theme->m_name = name;
+        m_themes.insert( PoolThemes::value_type( name, new_theme ) );
+    }
+
+    return true;
+}
