@@ -66,16 +66,15 @@ typedef std::vector< Entry* >::iterator		Entryiterv;
 class Diary : public DiaryBase, public DiaryElement
 {
 	public:
-		typedef unsigned int FilteringStatus;
-		static const FilteringStatus FS_CLEAR 				= 0;
-		static const FilteringStatus FS_FILTER_TEXT 		= 2;
-		static const FilteringStatus FS_FILTER_FAVORITES 	= 4;
-		static const FilteringStatus FS_FILTER_TAG 			= 8;
-		static const FilteringStatus FS_FILTER				= 14;
-		static const FilteringStatus FS_NEW 				= 1024;
+        typedef unsigned int FilteringStatus;
+        static const FilteringStatus FS_CLEAR               = 0;
+        static const FilteringStatus FS_FILTER_TEXT         = 2;
+        static const FilteringStatus FS_FILTER_FAVORITES    = 4;
+        static const FilteringStatus FS_FILTER_TAG          = 8;
+        static const FilteringStatus FS_FILTER_DATE         = 16;
+        static const FilteringStatus FS_NEW                 = 1024;
 
-		struct Shower { virtual void show( Diary& ) = 0; };
-		static Shower			*shower;
+		static ElementShower< Diary > *shower;
 
 								Diary( void );
 								Diary( const std::string& );	// locks diary file
@@ -94,8 +93,8 @@ class Diary : public DiaryBase, public DiaryElement
 
 		LIFEO::Result			write( void );
 		LIFEO::Result			write( const std::string& );
-		LIFEO::Result			write_copy( const std::string&, const std::string& );
-		LIFEO::Result			write_txt( const std::string& );
+		LIFEO::Result			write_copy( const std::string&, const std::string&, bool );
+		LIFEO::Result			write_txt( const std::string&, bool );
 
 		virtual void			clear( void );
 
@@ -128,13 +127,13 @@ class Diary : public DiaryBase, public DiaryElement
 		DiaryElement*			get_most_current_elem( void );
 		DiaryElement*			get_prev_session_elem( void );
 
-		Entry*					get_entry( const Date& );
+		Entry*					get_entry( const Date::date_t );
 		Entryvector*			get_entries( Date::date_t );
 		PoolEntries&			get_entries( void )
 		{ return m_entries; }
 		bool					get_day_has_multiple_entries( const Date& );
 		Entry*					get_entry_today( void );
-		Entry*					get_entry_nextinday( const Date& );
+		Entry*					get_entry_next_in_day( const Date& );
 		Entry*					get_entry_first( void );
 		void					set_entry_date( Entry*, const Date& );
 		//int						get_entrydayorder( const Entry * const ) const;
@@ -153,6 +152,14 @@ class Diary : public DiaryBase, public DiaryElement
 		const Tag*				get_filter_tag( void ) const
 		{ return m_filter_tag; }
 		void					toggle_filter_favorites( void );
+        Date::date_t            get_filter_date_begin( void )
+        { return m_filter_date_begin; }
+        Date::date_t            get_filter_date_end( void )
+        { return m_filter_date_end; }
+        void                    set_filter_date_begin( Date::date_t d );
+        void                    set_filter_date_end( Date::date_t d );
+        void                    activate_individual_filter( void );
+        void                    clear_filter_date( void );
 
 		FilteringStatus			get_filtering_status( void ) const
 		{	return m_filtering_status; }
@@ -202,7 +209,7 @@ class Diary : public DiaryBase, public DiaryElement
 		{ return( ! m_passphrase.empty() ); }
 
 		Theme*					create_theme( const Glib::ustring& );
-		Theme*					duplicate_theme( const Theme &theme );
+		Theme*					duplicate_theme( const Theme *theme );
 		bool					has_theme( void ) const
 		{ return( m_default_theme != NULL ); }
 		const PoolThemes&		get_themes( void ) const
@@ -219,6 +226,7 @@ class Diary : public DiaryBase, public DiaryElement
 
 		bool					import_tag( Tag* );
 		bool					import_entryset( const PoolEntries&, bool, const Glib::ustring& );
+		bool					import_themes( const PoolThemes& );
 
 	protected:
 		std::string				m_path;
@@ -239,9 +247,12 @@ class Diary : public DiaryBase, public DiaryElement
 		bool					m_option_spellcheck;
 		SortingCriteria			m_option_sorting_criteria;
 		int						m_read_version;
+		bool                    m_flag_only_save_filtered;
 		// filtering
 		Glib::ustring			m_filter_text;
 		const Tag				*m_filter_tag;
+        Date::date_t            m_filter_date_begin;
+        Date::date_t            m_filter_date_end;
 		FilteringStatus			m_filtering_status;
 
 		LIFEO::Result			parse_db_body_text( std::stringstream& );
