@@ -61,7 +61,7 @@ DiaryElement::DiaryElement( DiaryBase * const ptr2diary, const Glib::ustring &na
 
 // TAG =========================================================================
 // STATIC MEMBERS
-Tag::Shower		*Tag::shower = NULL;
+ElementShower< Tag >    *Tag::shower( NULL );
 
 Tag::Tag( DiaryBase * const d, const Glib::ustring &name, CategoryTags *category )
 :	DiaryElementContainer( d, name ), m_ptr2category( category )
@@ -105,7 +105,7 @@ Tag::set_category( CategoryTags *category_new )
 	m_ptr2category = category_new;
 }
 
-// TAGPOOL =====================================================================
+// TAGPOOL =========================================================================================
 PoolTags::~PoolTags()
 {
 	for( iterator iter = begin(); iter != end(); ++iter )
@@ -150,9 +150,9 @@ PoolTags::clear( void )
 	std::map< Glib::ustring, Tag*, FuncCompareStrings >::clear();
 }
 
-// CATEGORYTAGS ================================================================
+// CATEGORYTAGS ====================================================================================
 // STATIC MEMBERS
-CategoryTags::Shower		*CategoryTags::shower;
+ElementShower< CategoryTags >   *CategoryTags::shower( NULL );
 
 CategoryTags::CategoryTags( DiaryBase * const d, const Glib::ustring &name )
 :	DiaryElement( d, name ), std::set< Tag*, FuncCompareDiaryElemNamed >( compare_listitems_by_name ),
@@ -248,9 +248,9 @@ Tagset::get_tag( unsigned int tagorder ) const
 	return NULL;
 }
 
-// CHAPTER =====================================================================
+// CHAPTER =========================================================================================
 // STATIC MEMBERS
-Chapter::Shower		*Chapter::shower;
+ElementShower< Chapter >    *Chapter::shower( NULL );
 
 Chapter::Chapter( DiaryBase * const d, const Glib::ustring &name )
 :	DiaryElement( d, name ), m_date_begin( Date::NOTSET ), m_size( 0 ),
@@ -323,7 +323,7 @@ Chapter::get_free_order( void ) const
 	return date;
 }
 
-// CHAPTER CATEGORY ============================================================
+// CHAPTER CATEGORY ================================================================================
 CategoryChapters::CategoryChapters( DiaryBase * const d, const Glib::ustring &name )
 :	DiaryElement( d, name ),
 	std::map< Date::date_t, Chapter*, FuncCompareDates >( compare_dates )
@@ -465,7 +465,7 @@ PoolCategoriesChapters::clear( void )
 
 // THEMES ======================================================================
 // STATIC MEMBERS
-Theme::Shower		*Theme::shower = NULL;
+ElementShower< Theme >  *Theme::shower( NULL );
 
 Theme::Theme( DiaryBase * const d, const Glib::ustring &name )
 :	DiaryElement( d, name ),
@@ -492,6 +492,17 @@ Theme::Theme( DiaryBase * const d,
 {
 }
 
+Theme::Theme( const Theme *theme )
+:   DiaryElement( theme->m_ptr2diary, theme->m_name ),
+    font( theme->font ),
+    color_base( theme->color_base ),
+    color_text( theme->color_text ),
+    color_heading( theme->color_heading ),
+    color_subheading( theme->color_subheading ),
+    color_highlight( theme->color_highlight )
+{
+}
+
 Glib::RefPtr< Gdk::Pixbuf >&
 Theme::get_icon( void ) const
 {
@@ -545,8 +556,9 @@ ThemeSystem::get( void )
 // POOLTHEMES ==================================================================
 PoolThemes::~PoolThemes()
 {
-	for( iterator iter = begin(); iter != end(); ++iter )
-		delete iter->second;
+    for( iterator iter = begin(); iter != end(); ++iter )
+        if( ! iter->second->is_system() )
+            delete iter->second;
 }
 
 void
