@@ -55,8 +55,9 @@ class DiaryBase
 		typedef std::map< DEID, DiaryElement* >
 									PoolDEIDs;
 
-									DiaryBase( void )
+                                    DiaryBase( void )
 		:	m_current_id( DEID_MIN ), m_force_id( DEID_UNSET ) {}
+		virtual                     ~DiaryBase() { }
 
 		DEID						create_new_id( DiaryElement *element )
 		{
@@ -66,17 +67,12 @@ class DiaryBase
 			else
 			{
 				retval = m_force_id;
-				if( m_force_id > m_current_id )
-					m_current_id = m_force_id;
 				m_force_id = DEID_UNSET;
 			}
 			m_ids[ retval ] = element;
 
-			do
-			{
+			while( m_ids.find( m_current_id ) != m_ids.end() )
 				m_current_id++;
-			}
-			while( m_ids.find( m_current_id ) != m_ids.end() );
 
 			return retval;
 		}
@@ -107,7 +103,7 @@ class DiaryBase
 
 class ListData;	// forward declaration
 
-// DIARYELEMENT
+// DIARYELEMENT ====================================================================================
 class NamedElement
 {
 	public:
@@ -115,6 +111,7 @@ class NamedElement
 								:	m_name( "" ) {}
 								NamedElement( const Glib::ustring &name )
 								:	m_name( name ) {}
+		virtual                 ~NamedElement() {}  //needed because of virtual methods
 
 		virtual Glib::ustring	get_name( void ) const
 		{ return m_name; }
@@ -132,9 +129,9 @@ class DiaryElement : public NamedElement
 
 		enum Type
 		{
-			IT_NONE, IT_UNTAGGED, IT_TAG, IT_TAG_CATEGORY, IT_THEME,
+			IT_NONE, IT_TAG, IT_TAG_CATEGORY, IT_THEME,
 			// entry list elements:
-			IT_DIARY, IT_EARLIER, IT_CHAPTER, IT_ENTRY, IT_DATE
+			IT_DIARY, IT_CHAPTER, IT_ENTRY, IT_DATE
 		};
 
 								DiaryElement( DiaryBase * const,
@@ -215,6 +212,16 @@ create_unique_name_for_map( const std::map< Glib::ustring, T*, FuncCompareString
 	return name;
 }
 
+// ElementShower class is for communication between Diary and...
+// ...GUI classes. we may resort to signals if needed:
+template< class T >
+struct ElementShower
+{
+        virtual         ~ElementShower() {}
+        virtual void    show( T& ) = 0;
+        virtual void    prepare_for_hiding( T& ) {}
+};
+
 class DiaryElementContainer : public DiaryElement
 {
 // NOTE: this class and its derivatives are not responsible for handling of...
@@ -238,8 +245,7 @@ class DiaryElementContainer : public DiaryElement
 		SetDiaryElements		m_items;
 };
 
-
-// TAG =========================================================================
+// TAG =============================================================================================
 class Tag;	// forward declaration
 
 // TAG CATEGORY
@@ -247,8 +253,7 @@ class Tag;	// forward declaration
 class CategoryTags : public DiaryElement, public std::set< Tag*, FuncCompareDiaryElemNamed >
 {
 	public:
-		struct Shower { virtual void show( CategoryTags& ) = 0; };
-		static Shower			*shower;
+		static ElementShower< CategoryTags > *shower;
 
 								CategoryTags( DiaryBase * const, const Glib::ustring& );
 
@@ -292,8 +297,7 @@ class PoolCategoriesTags : public std::map< Glib::ustring, CategoryTags*, FuncCo
 class Tag : public DiaryElementContainer
 {
 	public:
-		struct Shower { virtual void show( Tag& ) = 0; };
-		static Shower			*shower;
+		static ElementShower< Tag > *shower;
 
 								Tag( DiaryBase * const d )
 								:	DiaryElementContainer( d ),
@@ -358,12 +362,11 @@ class Tagset : public std::set< Tag*, FuncCompareDiaryElemNamed >
 
 };
 
-// CHAPTER =====================================================================
+// CHAPTER =========================================================================================
 class Chapter : public DiaryElement
 {
 	public:
-		struct Shower { virtual void show( Chapter& ) = 0; };
-		static Shower			*shower;
+        static ElementShower< Chapter > *shower;
 
 		explicit				Chapter( DiaryBase * const, const Glib::ustring& );
 								Chapter( DiaryBase * const, const Glib::ustring&, Date );
@@ -457,23 +460,23 @@ class PoolCategoriesChapters :
 		void						clear( void );
 };
 
-// THEMES
+// THEMES ==========================================================================================
 class Theme : public DiaryElement
 {
 	public:
-		// Shower sub-class is for communication between Theme and...
-		// ...ThemeView classes. we may resort to the sigc::signals if needed:
-		struct Shower { virtual void show( Theme& ) = 0; };
+        static ElementShower< Theme > *shower;
 
-									Theme( DiaryBase * const, const Glib::ustring& );
-									Theme( DiaryBase * const,
-										   const Glib::ustring&,
-										   const Glib::ustring&,
-										   const std::string&,
-										   const std::string&,
-										   const std::string&,
-										   const std::string&,
-										   const std::string& );
+                                    Theme( DiaryBase * const, const Glib::ustring& );
+                                    Theme( DiaryBase * const,
+                                           const Glib::ustring&,
+                                           const Glib::ustring&,
+                                           const std::string&,
+                                           const std::string&,
+                                           const std::string&,
+                                           const std::string&,
+                                           const std::string& );
+        // duplicates an existing theme, works like a copy constructor
+                                    Theme( const Theme* );
 
 		void						show( void );
 
@@ -497,8 +500,6 @@ class Theme : public DiaryElement
 		Gdk::Color					color_subheading;
 		Gdk::Color					color_highlight;
 
-		static Shower				*shower;
-
 	friend class Diary;
 };
 
