@@ -29,14 +29,14 @@ using namespace LIFEO;
 
 
 // STATIC MEMBERS
-Entry::Shower						*Entry::shower = NULL;
+ElementShower< Entry >  *Entry::shower( NULL );
 
 Entry::Entry( DiaryBase * const d, const Date &date, const Glib::ustring &text, bool flag_favored )
 :	DiaryElement( d ),
 	m_date( date ), m_date_created( date.get_ctime() ), m_date_changed( date.get_ctime() ),
 	m_text( text ), m_ptr2theme( NULL ),
 	m_option_favored( flag_favored ),
-	m_flag_filteredout( false ), m_flag_theme_is_set( false )
+	m_flag_filteredout( false )
 {
 	calculate_title( text );
 }
@@ -45,7 +45,7 @@ Entry::Entry( DiaryBase * const d, const Date &date, bool flag_favored )
 :	DiaryElement( d, _( "<empty entry>" ) ),
 	m_date( date ), m_date_created( date.get_ctime() ), m_date_changed( date.get_ctime() ),
 	m_text( "" ), m_ptr2theme( NULL ), m_option_favored( flag_favored ),
-	m_flag_filteredout( false ), m_flag_theme_is_set( false )
+	m_flag_filteredout( false )
 {
 }
 
@@ -66,7 +66,7 @@ Entry::calculate_title( const Glib::ustring &text )
 		return;
 	}
 	unsigned int l_pos = text.find( '\n', 0 );
-	if( l_pos == Glib::ustring::npos )
+	if( l_pos == std::string::npos )
 		m_name = text;
 	else
 		m_name = text.substr( 0, l_pos );
@@ -133,19 +133,24 @@ Entry::get_filtered_out( void )
 	 
 	if( filtering_status & Diary::FS_NEW )	// recalculate
 	{
-		m_flag_filteredout = false;
+        m_flag_filteredout = false;
 
-		if( filtering_status == Diary::FS_NEW )	// FS_NEW alone means not applied clear
-			return false;
+        if( filtering_status == Diary::FS_NEW )	// FS_NEW alone means not applied clear
+            return false;
 
 		// cheapest first: favorites filter
-		if( filtering_status & Diary::FS_FILTER_FAVORITES )
-			if( ( m_flag_filteredout = ! m_option_favored ) )
-				return true; // no need to continue, already filtered out
+        if( filtering_status & Diary::FS_FILTER_FAVORITES )
+            if( ! m_option_favored )
+                return( m_flag_filteredout = true ); // no need to continue, already filtered out
 
-		if( filtering_status & Diary::FS_FILTER_TAG )
-			if( ( m_flag_filteredout = ! m_tags.checkfor_member( Diary::d->get_filter_tag() ) ) )
-				return true; // no need to continue, already filtered out
+        if( filtering_status & Diary::FS_FILTER_DATE )
+            if( ( m_date.m_date < Diary::d->get_filter_date_begin() ) ||
+                ( m_date.m_date > Diary::d->get_filter_date_end() ) )
+                return( m_flag_filteredout = true );
+
+        if( filtering_status & Diary::FS_FILTER_TAG )
+            if( ! m_tags.checkfor_member( Diary::d->get_filter_tag() ) )
+                return( m_flag_filteredout = true ); // no need to continue, already filtered out
 
 		if( filtering_status & Diary::FS_FILTER_TEXT )
 			m_flag_filteredout =
