@@ -33,11 +33,7 @@ namespace LIFEO
 class Entry : virtual public DiaryElement
 {
 	public:
-		struct Shower
-		{
-			virtual void show( Entry& ) = 0;
-			virtual void prepare_for_hiding( Entry& ) = 0;
-		};
+		static ElementShower< Entry > *shower;
 
 	typedef sigc::signal< void, Entry* >
 								Signal_void_Entry;
@@ -49,7 +45,7 @@ class Entry : virtual public DiaryElement
 		void					show( void );
 		void					prepare_for_hiding( void );
 
-		const Glib::ustring&	get_text() const { return m_text; }
+		const Glib::ustring*	get_text() const { return &m_text; }
 		Glib::ustring&			get_text() { return m_text; }
 		void					set_text( const Glib::ustring &text )
 		{ m_text = text; calculate_title( text ); }
@@ -91,22 +87,19 @@ class Entry : virtual public DiaryElement
 		bool					add_tag( Tag* );
 		bool					remove_tag( Tag* );
 
-		// NULL means system theme
+		// NULL means theme is not set
 		const Theme*			get_theme( void ) const
 		{
-			if( ! m_flag_theme_is_set )
-				throw LIFEO::Error( "Illegal theme request" );
-			return m_ptr2theme != NULL ? m_ptr2theme : ThemeSystem::get();
+            if( m_ptr2theme == NULL )   // FIXME: is this necessary?
+                throw LIFEO::Error( "Illegal theme request" );
+            return m_ptr2theme;
 		}
 		void					set_theme( const Theme *theme )
-		{
-			m_ptr2theme = ( theme ? ( theme->is_system() ? NULL : theme ) : NULL );
-			m_flag_theme_is_set = true;
-		}
+		{ m_ptr2theme = theme; }
 		void					unset_theme( void )
-		{ m_flag_theme_is_set = false; }
-		bool					get_theme_is_set( void )
-		{ return m_flag_theme_is_set; }
+		{ m_ptr2theme = NULL; }
+		bool					get_theme_is_set( void ) const
+		{ return( m_ptr2theme != NULL ); }
 
 	protected:
 		Date					m_date;
@@ -119,10 +112,6 @@ class Entry : virtual public DiaryElement
 		bool					m_option_favored;
 		//bool					m_option_spellcheck;	// TODO: per entry spellcheck
 		bool					m_flag_filteredout;
-		bool					m_flag_theme_is_set;
-
-		// GUI data
-		static Shower			*shower;
 
 	friend class Diary;	// TODO: remove this friendship too??
 	friend class DiaryView;	// TODO: remove this friendship too??
