@@ -193,7 +193,7 @@ TagWidget::compare_text( const Glib::ustring &text,
 		return(	Glib::Unicode::tolower( tagname[ 0 ] ) ==
 				Glib::Unicode::tolower( text[ 0 ] ) );
 	else
-		return( tagname.lowercase().find( text.lowercase() ) != Glib::ustring::npos );
+		return( tagname.lowercase().find( text.lowercase() ) != std::string::npos );
 }
 
 void
@@ -228,7 +228,7 @@ TagWidget::populate( void )
 	}
 }
 
-// TAG PANEL ===================================================================
+// TAG PANEL =======================================================================================
 // STATIC MEMBERS
 TagPanel::Colrec		*TagPanel::colrec;
 
@@ -245,7 +245,6 @@ TagPanel::TagPanel( void )
 
 		Lifeobase::builder->get_widget( "treeview_all_tags", m_treeview_all_tags );
 		Lifeobase::builder->get_widget( "hbox_tagbar", m_hbox_tagbar );
-		Lifeobase::builder->get_widget( "button_tag_remove_filter", m_button_remove_filter );
 
 		cellrenderer_icon = Gtk::manage( new Gtk::CellRendererPixbuf );
 		cellrenderer_name = Gtk::manage( new Gtk::CellRendererText );
@@ -292,9 +291,6 @@ TagPanel::TagPanel( void )
 			sigc::mem_fun( this, &TagPanel::handle_treeview_row_expanded ) );
 	m_treeview_all_tags->signal_row_collapsed().connect(
 			sigc::mem_fun( this, &TagPanel::handle_treeview_row_expanded ) );
-
-	m_button_remove_filter->signal_clicked().connect(
-			sigc::mem_fun( this, &TagPanel::handle_remove_filter ) );
 }
 
 void
@@ -476,7 +472,6 @@ TagPanel::handle_treeview_row_activated( const Gtk::TreePath &path, Gtk::TreeVie
 		if( tag == Diary::d->get_filter_tag() )	// remove filter
 		{
 			Diary::d->set_filter_tag( NULL );
-			Lifeobase::base->update_filter_tag();
 			row[ colrec->icon ] = Lifeobase::icons->tag_16;
 		}
 		else
@@ -488,19 +483,10 @@ TagPanel::handle_treeview_row_activated( const Gtk::TreePath &path, Gtk::TreeVie
 				row_old[ colrec->icon ] = Lifeobase::icons->tag_16;
 			}
 			Diary::d->set_filter_tag( tag );
-			Lifeobase::base->update_filter_tag();
 			row[ colrec->icon ] = Lifeobase::icons->filter_16;
 		}
+        Lifeobase::base->update_button_filter_tag();
+        Lifeobase::base->update_button_remove_filters();
+        Lifeobase::base->update_entry_list();
 	}
 }
-
-void
-TagPanel::handle_remove_filter( void )
-{
-	// it is assumed that filter tag cannot be NULL here:
-	Gtk::TreeRow row( * m_treestore_all_tags->get_iter(
-			Diary::d->get_filter_tag()->m_list_data->treepath ) );
-	row[ colrec->icon ] = Lifeobase::icons->tag_16;
-	Diary::d->set_filter_tag( NULL );
-	Lifeobase::base->update_filter_tag();
-}
