@@ -337,6 +337,15 @@ LIFEO::midtone( const Gdk::Color &c1, const Gdk::Color &c2 )
 	return midtone;
 }
 
+Gdk::Color
+LIFEO::midtone( const Gdk::Color &c1, const Gdk::Color &c2, float ratio )
+{
+    Gdk::Color midtone;
+    midtone.set_red( ( c1.get_red() * ratio ) + ( c2.get_red() * ( 1.0 - ratio ) ) );
+    midtone.set_green( ( c1.get_green() * ratio ) + ( c2.get_green() * ( 1.0 - ratio ) ) );
+    midtone.set_blue( ( c1.get_blue() * ratio ) + ( c2.get_blue() * ( 1.0 - ratio ) ) );
+    return midtone;
+}
 // FILE FUNCTIONS
 std::ios::pos_type
 LIFEO::get_file_size( std::ifstream &file )
@@ -595,7 +604,7 @@ LIFEO::create_menuitem_markup(	const Glib::ustring &str_markup,
 	return menuitem;
 }
 
-// ENTRYIDLETEXT
+// ENTRYIDLETEXT ===================================================================================
 EntryIdletext::EntryIdletext( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& )
 	:	Gtk::Entry( cobject ), m_flag_empty( true )
 {
@@ -633,15 +642,21 @@ EntryIdletext::on_map( void )
 void
 EntryIdletext::on_changed( void )
 {
-	m_flag_empty = get_text().empty();
+    m_flag_empty = get_text().empty();
 
-	if( m_flag_empty )
-		// Fall-back to C API as gtkmm has problems with this:
-		gtk_entry_set_icon_from_stock( gobj(), GTK_ENTRY_ICON_SECONDARY, 0 );
-	else
-		set_icon_from_stock( Gtk::Stock::CLEAR, Gtk::ENTRY_ICON_SECONDARY );
+    if( m_flag_empty )
+    {
+        // Fall-back to C API as gtkmm has problems with this:
+        gtk_entry_set_icon_from_stock( gobj(), GTK_ENTRY_ICON_SECONDARY, 0 );
+        set_icon_activatable( false, Gtk::ENTRY_ICON_SECONDARY );
+    }
+    else
+    {
+        set_icon_from_stock( Gtk::Stock::CLEAR, Gtk::ENTRY_ICON_SECONDARY );
+        set_icon_activatable( true, Gtk::ENTRY_ICON_SECONDARY );
+    }
 
-	Gtk::Entry::on_changed();
+    Gtk::Entry::on_changed();
 }
 
 bool
@@ -671,7 +686,9 @@ EntryIdletext::on_key_release_event( GdkEventKey *event )
 	return Gtk::Entry::on_key_release_event( event );
 }
 
-// MENUBUTTON ==================================================================
+// MENUBUTTON ======================================================================================
+Glib::ustring       Menubutton::s_builder_name;
+
 Menubutton::Menubutton(	const Gtk::StockID &stockid,
 						const Glib::ustring &label,
 						Gtk::ReliefStyle style,
@@ -683,19 +700,16 @@ Menubutton::Menubutton(	const Gtk::StockID &stockid,
 
 	if( menu == NULL )
 		m_menu = new Menu2;
-	m_hbox = Gtk::manage( new Gtk::HBox );
-	m_vbox = Gtk::manage( new Gtk::VBox );
+	Gtk::HBox *hbox = Gtk::manage( new Gtk::HBox );
 	m_icon = Gtk::manage( new Gtk::Image( stockid, iconsize ) );
 	m_label = Gtk::manage( new Gtk::Label( label ) );
 	Gtk::Arrow *arrow = Gtk::manage(
 			new Gtk::Arrow(Gtk::ARROW_DOWN, Gtk::SHADOW_IN) );
 
-	m_hbox->pack_start(*m_vbox, Gtk::PACK_SHRINK);
-	// the only purpose of Vbox is supporting Gtk::TOOLBAR_BOTH toolbar style
-	m_vbox->pack_start( *m_icon, Gtk::PACK_SHRINK );
-	m_hbox->pack_start( *m_label, Gtk::PACK_EXPAND_WIDGET );
-	m_hbox->pack_start( *arrow, Gtk::PACK_SHRINK );
-	add( *m_hbox );
+	hbox->pack_start( *m_icon, Gtk::PACK_SHRINK );
+	hbox->pack_start( *m_label, Gtk::PACK_EXPAND_WIDGET );
+	hbox->pack_start( *arrow, Gtk::PACK_SHRINK );
+	add( *hbox );
 	m_menu->attach_to_widget( *this );
 	m_menu->signal_deactivate().connect( sigc::mem_fun( *this, &Menubutton::release ) );
 	add_events( Gdk::BUTTON_PRESS_MASK );
@@ -703,20 +717,19 @@ Menubutton::Menubutton(	const Gtk::StockID &stockid,
 
 //FIXME: code duplication
 Menubutton::Menubutton(	const Glib::RefPtr< Gdk::Pixbuf > *pixbuf,
-						const Glib::ustring& label,
+						const Glib::ustring &label,
 						Gtk::ReliefStyle style,
 						Menu2 *menu )
-	:	Gtk::ToggleButton(), m_menu( menu )
+:   Gtk::ToggleButton(), m_menu( menu )
 {
 	set_relief( style );
 	Gtk::Arrow *arrow;
+	Gtk::HBox *hbox;
 	try
 	{
-
 		if( menu == NULL )
 			m_menu = new Menu2;
-		m_hbox = Gtk::manage( new Gtk::HBox );
-		m_vbox = Gtk::manage( new Gtk::VBox );
+		hbox = Gtk::manage( new Gtk::HBox );
 		if( pixbuf )
 			m_icon = Gtk::manage( new Gtk::Image( *pixbuf ) );
 		m_label = Gtk::manage( new Gtk::Label( label ) );
@@ -727,25 +740,43 @@ Menubutton::Menubutton(	const Glib::RefPtr< Gdk::Pixbuf > *pixbuf,
 		throw 0;	// TODO...
 	}
 
-	m_hbox->pack_start( *m_vbox, Gtk::PACK_SHRINK );
-	// the only purpose of Vbox is supporting Gtk::TOOLBAR_BOTH toolbar style
 	if( pixbuf )
-		m_vbox->pack_start( *m_icon, Gtk::PACK_SHRINK );
-	m_hbox->pack_start( *m_label, Gtk::PACK_EXPAND_WIDGET );
-	m_hbox->pack_start( *arrow, Gtk::PACK_SHRINK );
-	add( *m_hbox );
+		hbox->pack_start( *m_icon, Gtk::PACK_SHRINK );
+	hbox->pack_start( *m_label, Gtk::PACK_EXPAND_WIDGET );
+	hbox->pack_start( *arrow, Gtk::PACK_SHRINK );
+	add( *hbox );
 	m_menu->attach_to_widget( *this );
 	m_menu->signal_deactivate().connect( sigc::mem_fun( *this, &Menubutton::release ) );
 	add_events( Gdk::BUTTON_PRESS_MASK );
 }
 
+Menubutton::Menubutton( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder> &builder )
+:   Gtk::ToggleButton( cobject )
+{
+    try
+    {
+        builder->get_widget_derived( s_builder_name + "_menu", m_menu );
+        builder->get_widget( s_builder_name + "_icon", m_icon );
+        builder->get_widget( s_builder_name + "_label", m_label );
+        s_builder_name = "";
+    }
+    catch( ... )
+    {
+        throw LIFEO::Error( "Menubutton creation failed" );
+    }
+
+    m_menu->attach_to_widget( *this );
+    m_menu->signal_deactivate().connect( sigc::mem_fun( this, &Menubutton::release ) );
+    add_events( Gdk::BUTTON_PRESS_MASK );
+}
+
 Menubutton::~Menubutton( void )
 {
 	delete m_menu;
 }
 
 Menu2*
-Menubutton::get_menu( void )
+Menubutton::get_menu( void ) const
 {
 	return m_menu;
 }
@@ -779,7 +810,7 @@ Menubutton::set_label( const Glib::ustring& string )
 }
 
 void
-Menubutton::get_menu_position (int& x, int& y, bool& push_in)
+Menubutton::get_menu_position( int& x, int& y, bool& push_in )
 {
 	get_window()->get_origin( x, y );
 	x += get_allocation().get_x();
@@ -788,7 +819,7 @@ Menubutton::get_menu_position (int& x, int& y, bool& push_in)
 }
 
 bool
-Menubutton::on_button_press_event (GdkEventButton *l_event)
+Menubutton::on_button_press_event( GdkEventButton *l_event )
 {
 	m_menu->popup( sigc::mem_fun(
 			*this, &Menubutton::get_menu_position), l_event->button, l_event->time);
@@ -799,6 +830,8 @@ Menubutton::on_button_press_event (GdkEventButton *l_event)
 }
 
 // MENUTOOLBUTTON
+/*
+ * TO BE REWRITTEN IF NEEDED IN THE FUTURE...
 Menutoolbutton::Menutoolbutton( const Gtk::StockID& stockid,
 							    const std::string& string,
 							    Menu2 *menu,
@@ -850,10 +883,11 @@ Menutoolbutton::on_toolbar_reconfigured (void)
 		break;
 	}
 }
+*/
 
-// MENUITEMRECENT
+// MENUITEMRECENT ==================================================================================
 MenuitemRecent::MenuitemRecent( const std::string &path )
-	:	Gtk::MenuItem(), m_icon_remove( Gtk::Stock::DELETE, Gtk::ICON_SIZE_MENU ),
+:	Gtk::MenuItem(), m_icon_remove( Gtk::Stock::DELETE, Gtk::ICON_SIZE_MENU ),
 	m_path( path ), m_flag_deletepressed( false )
 {
 	Gtk::Label		*label = Gtk::manage( new Gtk::Label(
@@ -924,43 +958,79 @@ MenuitemRecent::on_button_release_event( GdkEventButton *event )
 }
 
 
+// FILEBUTTONRECENT ================================================================================
+Glib::ustring   FilebuttonRecent::fallback_label = _( "Select or Create a Diary" );
 
-// FILEBUTTONRECENT
-FilebuttonRecent::FilebuttonRecent(	const Glib::RefPtr< Gdk::Pixbuf > &pixbuf,
-									ListPaths *list_recent,
-									const Glib::ustring& label_fallback )
-	:	Menubutton( &pixbuf, label_fallback, Gtk::RELIEF_NORMAL ),
-	m_icon_new( Gtk::Stock::NEW, Gtk::ICON_SIZE_MENU ),
-	m_icon_browse( Gtk::Stock::OPEN, Gtk::ICON_SIZE_MENU ),
-	m_list_recent( list_recent )
+/*
+FilebuttonRecent::FilebuttonRecent( const Glib::RefPtr< Gdk::Pixbuf > &pixbuf,
+                                    ListPaths *list_recent,
+                                    const Glib::ustring& label_fallback )
+:   Menubutton( &pixbuf, label_fallback, Gtk::RELIEF_NORMAL ),
+    m_icon_new( Gtk::Stock::NEW, Gtk::ICON_SIZE_MENU ),
+    m_icon_browse( Gtk::Stock::OPEN, Gtk::ICON_SIZE_MENU ),
+    m_list_recent( list_recent )
 {
-	m_hbox->set_spacing( 4 );
+    // TODO: m_hbox->set_spacing( 4 );
 
-	m_label->set_ellipsize( Pango::ELLIPSIZE_START );
-	m_label->set_alignment( Gtk::ALIGN_LEFT );
+    m_label->set_ellipsize( Pango::ELLIPSIZE_START );
+    m_label->set_alignment( Gtk::ALIGN_LEFT );
 
-	m_menu->items().push_back( Gtk::Menu_Helpers::SeparatorElem() );
+    m_menu->items().push_back( Gtk::Menu_Helpers::SeparatorElem() );
 
-	m_menu->items().push_back(
-			Gtk::Menu_Helpers::ImageMenuElem( _("_Browse For a Diary..."), m_icon_browse,
-					sigc::mem_fun( *this,
-							&FilebuttonRecent::show_filechooser) ) );
-	m_menu->items().push_back(
-			Gtk::Menu_Helpers::ImageMenuElem( _("_Create A New Diary..."), m_icon_new,
-					sigc::mem_fun( *this,
-							&FilebuttonRecent::on_create_file) ) );
+    m_menu->items().push_back(
+            Gtk::Menu_Helpers::ImageMenuElem( _("_Browse For a Diary..."), m_icon_browse,
+                    sigc::mem_fun( *this,
+                            &FilebuttonRecent::show_filechooser) ) );
+    m_menu->items().push_back(
+            Gtk::Menu_Helpers::ImageMenuElem( _("_Create A New Diary..."), m_icon_new,
+                    sigc::mem_fun( *this,
+                            &FilebuttonRecent::on_create_file) ) );
 
-	m_menu->show_all_children();
+    m_menu->show_all_children();
 
-	// ACCEPT DROPPED FILES
-	//~ std::list< Gtk::TargetEntry > list_targets;
-	//~ list_targets.push_back( Gtk::TargetEntry( "STRING" ) );
-	//~ list_targets.push_back( Gtk::TargetEntry( "text/plain" ) );
-	//~ this->drag_dest_set( list_targets );
-	// TODO: i could not figure out how this is supposed to work and replicated
-	// almost blindly bmpx' approach.
-	drag_dest_set( Gtk::DEST_DEFAULT_ALL, ( Gdk::ACTION_COPY | Gdk::ACTION_MOVE ) );
-	drag_dest_add_uri_targets();
+    // ACCEPT DROPPED FILES
+    //~ std::list< Gtk::TargetEntry > list_targets;
+    //~ list_targets.push_back( Gtk::TargetEntry( "STRING" ) );
+    //~ list_targets.push_back( Gtk::TargetEntry( "text/plain" ) );
+    //~ this->drag_dest_set( list_targets );
+    // TODO: i could not figure out how this is supposed to work and replicated
+    // almost blindly bmpx' approach.
+    drag_dest_set( Gtk::DEST_DEFAULT_ALL, ( Gdk::ACTION_COPY | Gdk::ACTION_MOVE ) );
+    drag_dest_add_uri_targets();
+}*/
+
+FilebuttonRecent::FilebuttonRecent( BaseObjectType *cobj, const Glib::RefPtr<Gtk::Builder> &bui )
+:   Menubutton( cobj, bui ),
+    m_icon_new( Gtk::Stock::NEW, Gtk::ICON_SIZE_MENU ),
+    m_icon_browse( Gtk::Stock::OPEN, Gtk::ICON_SIZE_MENU ),
+    m_list_recent( NULL )
+{
+    m_label->set_ellipsize( Pango::ELLIPSIZE_START );
+    m_label->set_alignment( Gtk::ALIGN_LEFT );
+    m_label->set_text( fallback_label );
+
+    m_menu->items().push_back( Gtk::Menu_Helpers::SeparatorElem() );
+
+    m_menu->items().push_back(
+            Gtk::Menu_Helpers::ImageMenuElem( _("_Browse For a Diary..."), m_icon_browse,
+                    sigc::mem_fun( *this,
+                            &FilebuttonRecent::show_filechooser) ) );
+    m_menu->items().push_back(
+            Gtk::Menu_Helpers::ImageMenuElem( _("_Create A New Diary..."), m_icon_new,
+                    sigc::mem_fun( *this,
+                            &FilebuttonRecent::on_create_file) ) );
+
+    m_menu->show_all_children();
+
+    // ACCEPT DROPPED FILES
+    drag_dest_set( Gtk::DEST_DEFAULT_ALL, ( Gdk::ACTION_COPY | Gdk::ACTION_MOVE ) );
+    drag_dest_add_uri_targets();
+}
+
+void
+FilebuttonRecent::set( ListPaths *list_recent )
+{
+    m_list_recent = list_recent;
 }
 
 std::string
@@ -1052,31 +1122,37 @@ FilebuttonRecent::add_recent( const std::string &path )
 void
 FilebuttonRecent::remove_recent( const std::string &path )
 {
-	Gtk::Menu_Helpers::MenuList::iterator	iter_menu = m_menu->items().begin();
-	std::list< std::string >::iterator		iter_recent = m_list_recent->begin();
-	bool flag_update = false;
-	for( ; iter_recent != m_list_recent->end(); ++iter_recent )
-	{
-		if( ( *iter_recent ) == path )
-		{
-			if( iter_recent == m_list_recent->begin() )
-				flag_update = true;
-			m_menu->items().erase( iter_menu );
-			m_list_recent->erase( iter_recent );
-			break;
-		}
-		else
-		{
-			++iter_menu;
-		}
-	}
-	// update current path if first item is deleted
-	if( flag_update )
-	{
-		m_label->set_label( Glib::filename_display_basename( m_list_recent->front() ) );
-		set_tooltip_text( m_list_recent->front() );
-		m_signal_selectionchanged.emit();
-	}
+    Gtk::Menu_Helpers::MenuList::iterator	iter_menu = m_menu->items().begin();
+    std::list< std::string >::iterator		iter_recent = m_list_recent->begin();
+    bool flag_update = false;
+    for( ; iter_recent != m_list_recent->end(); ++iter_recent )
+    {
+        if( ( *iter_recent ) == path )
+        {
+            if( iter_recent == m_list_recent->begin() )
+                flag_update = true;
+            m_menu->items().erase( iter_menu );
+            m_list_recent->erase( iter_recent );
+            break;
+        }
+        else
+            ++iter_menu;
+    }
+    // update current path if first item is deleted
+    if( flag_update )
+    {
+        if( m_list_recent->empty() )
+        {
+            m_label->set_label( fallback_label );
+            set_tooltip_text( "" );
+        }
+        else
+        {
+            m_label->set_label( Glib::filename_display_basename( m_list_recent->front() ) );
+            set_tooltip_text( m_list_recent->front() );
+        }
+        m_signal_selectionchanged.emit();
+    }
 }
 
 void
