@@ -1,6 +1,6 @@
 /***********************************************************************************
 
-	Copyright (C) 2007-2011 Ahmet Öztürk (aoz_2@yahoo.com)
+	Copyright (C) 2007-2012 Ahmet Öztürk (aoz_2@yahoo.com)
 
 	This file is part of Lifeograph.
 
@@ -33,8 +33,8 @@
 namespace LIFEO
 {
 	const char			PROGRAM_NAME[]				= "Lifeograph";
-	const int			PROGRAM_VERSION_INT			= 7040;
-	const char			PROGRAM_VERSION_STRING[]	= "0.7.4";
+	const int			PROGRAM_VERSION_INT			= 8010;
+	const char			PROGRAM_VERSION_STRING[]	= "0.8.1";
 
 	const int			BACKUP_INTERVAL				= 30;	// seconds
 	const int			LOGOUT_COUNTDOWN			= 10;	// seconds
@@ -113,8 +113,9 @@ class Lifeobase : public Gtk::Window
 		virtual void				update_entry_list( void ) = 0;
 		virtual void				update_tag_list( void ) = 0;
 		virtual void				update_calendar( void ) = 0;
-		virtual void				update_filter_tag( void ) = 0;
-		virtual void				update_tag_icon( Tag* ) = 0;
+		virtual void				update_button_filter_tag( void ) = 0;
+		virtual void				update_button_remove_filters( void ) = 0;
+		virtual void				update_tag_icon( const Tag* ) = 0;
 		virtual void				update_tag_categories( void ) = 0;
 		virtual void				select_date_in_calendar( const Date& ) = 0;
 		virtual void				update_theme_list( void ) = 0;
@@ -129,6 +130,7 @@ class Lifeobase : public Gtk::Window
 		virtual DiaryElement*		get_dragged_elem( void ) = 0;
 		virtual Gtk::TreeRow		get_element_row( DiaryElement* ) = 0;
 		virtual void				focus_tag( void ) = 0;
+		virtual void				toggle_comments( void ) = 0;
 
 		int							m_secondsremaining;
 		static int					m_internaloperation;
@@ -155,8 +157,6 @@ class Lifeobase : public Gtk::Window
 	protected:
 		static sigc::connection		m_connection_timeout;
 
-		virtual bool				on_expose_event( GdkEventExpose* ) = 0;
-
 		static Glib::RefPtr< Gtk::ActionGroup >
 									m_actions;
 
@@ -166,9 +166,9 @@ class Lifeobase : public Gtk::Window
 class DialogEvent : public Gtk::Dialog
 {
 	public:
-							DialogEvent( const Glib::ustring& );
-							DialogEvent(	BaseObjectType*,
-											const Glib::RefPtr< Gtk::Builder >& );
+                            DialogEvent( const Glib::ustring& );
+                            DialogEvent( BaseObjectType*,
+                                         const Glib::RefPtr< Gtk::Builder >& );
 
 	protected:
 		bool				on_event( GdkEvent* );
@@ -176,6 +176,19 @@ class DialogEvent : public Gtk::Dialog
 
 };
 
+// this is necessary to use ComboboxText together with Gtk::Builder
+// till we upgrade to Gtkmm 3:
+class ComboboxEasy : public Gtk::ComboBoxText
+{
+    public:
+                            ComboboxEasy( BaseObjectType* cobject,
+                                          const Glib::RefPtr< Gtk::Builder >& )
+    :   Gtk::ComboBoxText( cobject ) {}
+};
+
+
+Gtk::Frame* create_frame( const Glib::ustring&, Gtk::Widget& );
+
 } // end of namespace LIFEO
 
 #endif
