@@ -40,10 +40,12 @@ Lifeograph::Lifeograph( int argc, char *argv[] )
 	m_theme_view( NULL ),
 	m_programpath( argv[ 0 ] ), m_loginstatus( LOGGED_OUT ),
 #ifdef LIFEOGRAPH_DEBUG_BUILD
-	m_flag_ignore_locks( true )
+	m_flag_ignore_locks( true ),
 #else
-	m_flag_ignore_locks( false )
+	m_flag_ignore_locks( false ),
 #endif
+	m_flag_open_directly( false ),
+	m_flag_force_welcome( false )
 {
 	Cipher::init();
 
@@ -63,7 +65,6 @@ Lifeograph::Lifeograph( int argc, char *argv[] )
 		move( m_settings.position_x, m_settings.position_y );
 
 	// COMMANDLINE OPTIONS
-	bool  force_welcome( false );
 	for( int i = 1; i < argc; i++ )
 	{
 		if( ! strcmp( argv[ i ], "--open" ) || ! strcmp( argv[ i ], "-o" ) )
@@ -72,24 +73,19 @@ Lifeograph::Lifeograph( int argc, char *argv[] )
 			{
 				if( Glib::file_test( argv[ ++i ], Glib::FILE_TEST_EXISTS ) )
 					if( ! Glib::file_test( argv[ i ], Glib::FILE_TEST_IS_DIR ) )
+					{
 						// TODO: detect duplicates?
 						m_settings.recentfiles.push_front( argv[ i ] );
+						m_flag_open_directly = true;
+					}
 			}
 			else
 				Error( "No path provided" );
 		}
 		else
-		if( ! strcmp( argv[ i ], "--set-bg" ) )
-		{
-			if( i < argc )
-				m_settings.background = argv[ ++i ];
-			else
-				Error( "No path provided" );
-		}
-		else
 		if( ! strcmp( argv[ i ], "--force-welcome" ) )
 		{
-			force_welcome = true;
+			m_flag_force_welcome = true;
 		}
 		else
 		if( ! strcmp( argv[ i ], "--ignore-locks" ) )
@@ -100,45 +96,21 @@ Lifeograph::Lifeograph( int argc, char *argv[] )
 		if( Glib::file_test( argv[ i ], Glib::FILE_TEST_EXISTS ) )
 		{
 			if( ! Glib::file_test( argv[ i ], Glib::FILE_TEST_IS_DIR ) )
+			{
 				m_settings.recentfiles.push_front( argv[ i ] );
-		}
-	}
-
-	// BACKGROUND PICTURE
-	if( m_settings.background != "none" )	// not disabled
-	{
-		try
-		{
-			pixbuf_background = Gdk::Pixbuf::create_from_file( m_settings.background );
-		}
-		catch( Glib::Error &ex )
-		{
-			try
-			{
-				// try to use the default bg picture:
-				m_settings.background = PIXMAPDIR "/lifeograph/backgrounds/bg.png";
-				pixbuf_background = Gdk::Pixbuf::create_from_file( m_settings.background );
-			}
-			catch( Glib::Error &ex )
-			{
-				print_error( "unable to set the backgound picture" );
-				m_settings.background = "none";
+				m_flag_open_directly = true;
 			}
 		}
 	}
 
-	// DRAW INTERFACE
-	if( m_flag_firsttimeuser || force_welcome )
-		draw_welcomescreen();
-	else
-		draw_loginscreen();
+	// GTKBUILDER
+	load_gui( UIDIR "/lifeograph.ui" );
 
 	// PROGRAM-WIDE VARIABLE INITIALIZATIONS
 	Gtk::AboutDialog::set_url_hook( &open_url );
 	Gtk::AboutDialog::set_email_hook( &mail_to );
 
-	// GTKBUILDER
-	load_gui( UIDIR "/lifeograph.ui" );
+    Gtk::Main::signal_run().connect( sigc::mem_fun( this, &Lifeograph::on_run ) );
 }
 
 Lifeograph::~Lifeograph( void )
@@ -150,9 +122,13 @@ Lifeograph::~Lifeograph( void )
 }
 
 void
-Lifeograph::run( void )
+Lifeograph::on_run( void )
 {
-	Gtk::Main::run( *this );
+    // purpose of this function is calling draw functions after Gtk::Main::run()
+    if( m_flag_firsttimeuser || m_flag_force_welcome )
+        draw_welcomescreen();
+    else
+        draw_loginscreen();
 }
 
 bool
@@ -172,29 +148,6 @@ Lifeograph::on_event( GdkEvent* )
 	return false;
 }
 
-bool
-Lifeograph::on_expose_event( GdkEventExpose *event )
-{
-	if( m_loginstatus != LOGGED_IN && bool( pixbuf_background ) )
-	{
-		Glib::RefPtr< Gdk::GC > gc( get_style()->get_bg_gc( Gtk::STATE_NORMAL ) );
-		Gdk::Rectangle rect( &event->area );
-		gc->set_clip_rectangle( rect );
-		get_window()->draw_pixbuf(
-			gc,
-			pixbuf_background,
-			0, 0, 0, 0, -1, -1,
-			Gdk::RGB_DITHER_NONE, 0, 0 );
-
-		if( get_child() )
-			propagate_expose( *get_child(), event );
-
-		return true;
-	}
-	else
-		return Gtk::Widget::on_expose_event( event );
-}
-
 bool
 Lifeograph::on_delete_event( GdkEventAny* )
 {
@@ -237,13 +190,15 @@ Lifeograph::update_login_file( void )
 {
 	// TODO: this function needs to be optimized
 
-	m_entry_password->set_sensitive( false );
-	m_button_opendiary->set_sensitive( false );
+	bool flag_open_ready( false );
+	bool flag_encrypted( false );
 
 	// FIXME: this is not so elegant here:
-	if( m_filebuttonrecent->get_recentlist()->size() <= 0 )
+    if( m_filebuttonrecent->get_recentlist()->size() <= 0 )
 	{
-		m_label_startupmessage->set_label( _( "Welcome new user!" ) );
+		m_label_login_info->set_label( _( "Welcome new user!" ) );
+		m_button_open_diary->set_sensitive( false );
+        m_entry_password->set_visible( false );
 		return;
 	}
 
@@ -259,7 +214,7 @@ Lifeograph::update_login_file( void )
 			print_info( "ignored file lock" );
 		else
 		{
-			m_label_startupmessage->set_text( _( STRING::DIARY_LOCKED ) );
+			m_label_login_info->set_text( _( STRING::DIARY_LOCKED ) );
 			return;
 		}
 	}
@@ -269,37 +224,46 @@ Lifeograph::update_login_file( void )
 	switch( Diary::d->read_header() )
 	{
 		case SUCCESS:
-			if( Diary::d->is_encrypted() )
-			{
-				m_entry_password->set_sensitive( true );
-				if( m_loginstatus == LOGGED_TIME_OUT )
-					m_label_startupmessage->set_text( _( STRING::ENTER_PASSWORD_TIMEOUT ) );
-				else
-					m_label_startupmessage->set_text( _( STRING::ENTER_PASSWORD ) );
-				m_button_opendiary->set_sensitive( m_entry_password->get_text_length() > 0 );
+            flag_encrypted = Diary::d->is_encrypted();
+            if( flag_encrypted )
+            {
+                if( m_loginstatus == LOGGED_TIME_OUT )
+                    m_label_login_info->set_text( _( STRING::ENTER_PASSWORD_TIMEOUT ) );
+                else
+                    m_label_login_info->set_text( _( STRING::ENTER_PASSWORD ) );
+                flag_open_ready = ( m_entry_password->get_text_length() > 0 );
 			}
 			else
 			{
-				m_label_startupmessage->set_text( _( STRING::DB_IS_NOT_ENCRYPTED ) );
-				m_button_opendiary->set_sensitive( true );
+                m_label_login_info->set_text( _( STRING::DB_IS_NOT_ENCRYPTED ) );
+				flag_open_ready = true;
 			}
 			break;
 		case INCOMPATIBLE_FILE:
-			m_label_startupmessage->set_text( _( STRING::INCOMPATIBLE_DB ) );
+            m_label_login_info->set_text( _( STRING::INCOMPATIBLE_DB ) );
 			break;
 		case CORRUPT_FILE:
-			m_label_startupmessage->set_text( _( STRING::CORRUPT_DB ) );
+            m_label_login_info->set_text( _( STRING::CORRUPT_DB ) );
 			break;
 		default:
-			m_label_startupmessage->set_text( _( STRING::FAILED_TO_OPEN_DB ) );
-			break;
+            m_label_login_info->set_text( _( STRING::FAILED_TO_OPEN_DB ) );
+            break;
 	}
 
-	// FOCUS ADJUSTMENT
-	if( Diary::d->is_encrypted() )
-		m_entry_password->grab_focus();
-	else
-		m_button_opendiary->grab_focus();
+    if( flag_open_ready && ( ! flag_encrypted ) && m_flag_open_directly )
+    {
+        handle_button_opendb_clicked();
+        return;
+    }
+
+    m_button_open_diary->set_sensitive( flag_open_ready );
+    m_entry_password->set_visible( flag_encrypted );
+
+    // FOCUS ADJUSTMENT
+    if( flag_encrypted )
+        m_entry_password->grab_focus();
+    else
+        m_button_open_diary->grab_focus();
 }
 
 void
@@ -317,6 +281,7 @@ Lifeograph::handle_button_about_clicked( void )
 		Lifeobase::builder->get_widget( "aboutdialog", m_about_dialog );
 		m_about_dialog->set_name( PROGRAM_NAME );
 		m_about_dialog->set_version( PROGRAM_VERSION_STRING );
+		m_about_dialog->set_transient_for( *this );
 	}
 
 	m_about_dialog->run();
@@ -334,8 +299,8 @@ Lifeograph::handle_filebutton_db_selectionchanged( void )
 void
 Lifeograph::handle_entry_password_changed( void )
 {
-	if( Diary::d->is_path_set() )
-		m_button_opendiary->set_sensitive( m_entry_password->get_text_length() > 0 );
+    if( Diary::d->is_path_set() )
+        m_button_open_diary->set_sensitive( m_entry_password->get_text_length() > 0 );
 }
 
 void
@@ -343,7 +308,6 @@ Lifeograph::initialize_new_diary( void )
 {
 	DialogSaveDiary *dialogsavediary = new DialogSaveDiary;
 	dialogsavediary->set_current_folder( Glib::get_home_dir() );
-	dialogsavediary->set_do_overwrite_confirmation( true );
 
 	if( dialogsavediary->run() == Gtk::RESPONSE_ACCEPT )
 	{
@@ -404,7 +368,7 @@ Lifeograph::handle_button_opendb_clicked( void )
 			draw_editscreen();
 			break;
 		case WRONG_PASSWORD:
-			m_label_startupmessage->set_text( _( STRING::WRONG_PASSWORD ) );
+		    m_label_login_info->set_text( _( STRING::WRONG_PASSWORD ) );
 			m_entry_password->set_text( "" );
 			m_entry_password->set_sensitive( false );
 			sleep( 1 );
@@ -412,7 +376,7 @@ Lifeograph::handle_button_opendb_clicked( void )
 			m_entry_password->grab_focus();
 			break;
 		case CORRUPT_FILE:
-			m_label_startupmessage->set_text( _( STRING::CORRUPT_DB ) );
+		    m_label_login_info->set_text( _( STRING::CORRUPT_DB ) );
 			Diary::d->clear();	// clear partially read content if any
 			break;
 		default:
@@ -697,21 +661,23 @@ Lifeograph::update_tag_categories( void )
 }
 
 void
-Lifeograph::update_filter_tag( void )
+Lifeograph::update_button_filter_tag( void )
 {
-	Lifeobase::m_internaloperation++;
-
-	const Tag *tag_filter = Diary::d->get_filter_tag();
-	m_panel_tag->m_button_remove_filter->set_visible( tag_filter != NULL );
-	m_panel_diary->update_entry_list();
-	if( tag_filter == NULL )
-		m_tag_view->m_button_filter->set_active( false );
-
-	Lifeobase::m_internaloperation--;
+    Lifeobase::m_internaloperation++;
+    m_tag_view->m_button_filter->set_active( Diary::d->get_filter_tag() != NULL );
+    Lifeobase::m_internaloperation--;
 }
 
 void
-Lifeograph::update_tag_icon( Tag *tag )
+Lifeograph::update_button_remove_filters( void )
+{
+    m_panel_diary->m_button_remove_filters->set_visible(
+            Diary::d->get_filtering_status() &
+            ( Diary::FS_FILTER_DATE | Diary::FS_FILTER_TAG ) );
+}
+
+void
+Lifeograph::update_tag_icon( const Tag *tag )
 {
 	m_panel_tag->update_tag_icon( tag );
 }
@@ -781,6 +747,13 @@ Lifeograph::focus_tag( void )
 	m_entry_view->focus_tag();
 }
 
+void
+Lifeograph::toggle_comments( void )
+{
+    m_entry_view->m_button_toggle_comments->set_active(
+            ! m_entry_view->m_button_toggle_comments->get_active() );
+}
+
 void
 Lifeograph::select_date_in_calendar( const Date &date )
 {
@@ -826,113 +799,63 @@ Lifeograph::draw_welcomescreen( void )
 void
 Lifeograph::draw_loginscreen( void )
 {
-	remove();
+    remove();
 
-	if( m_vbox_login == NULL )
-	{
-		Gtk::Alignment		*align1, *align2;
-		Gtk::HBox			*hbox;
-		Gtk::Label			*label_diary, *label_password;
-		Gtk::Button			*button_about, *button_quit;
-		Gtk::HSeparator		*hseparator;
+    if( m_vbox_login == NULL )
+    {
+        Gtk::Button     *button_about;
+        Gtk::Button     *button_quit;
+        Gtk::Image      *image_about;
 
-		try {
-			m_vbox_login = new Gtk::VBox;
-			align1 = Gtk::manage( new Gtk::Alignment( 0.5, 0.5, 0.4, 0.1 ) );
-			align2 = Gtk::manage( new Gtk::Alignment( 1.0, 0.5, 0, 1.0 ) );
-			m_table_login = Gtk::manage( new Gtk::Table );
-			hbox = Gtk::manage( new Gtk::HBox );
-			label_diary = Gtk::manage( new Gtk::Label( _( "Diary:" ), 0, 0.5 ) );
-			label_password = Gtk::manage( new Gtk::Label( _( "Password:" ), 0, 0.5 ) );
-			m_label_startupmessage = Gtk::manage( new Gtk::Label( "", 0, 0.5 ) );
-			m_button_opendiary = Gtk::manage( new Gtk::Button( Gtk::Stock::OK ) );
-			m_entry_password = Gtk::manage( new Gtk::Entry );
-			button_about = Gtk::manage( new Gtk::Button( Gtk::Stock::ABOUT ) );
-			button_quit = Gtk::manage( new Gtk::Button( Gtk::Stock::QUIT ) );
-			hseparator = Gtk::manage( new Gtk::HSeparator );
-			m_filebuttonrecent = Gtk::manage( new LIFEO::FilebuttonRecent(
-					icons->diary_16, &m_settings.recentfiles, _( "Select or Create a Diary" ) ) );
-		}
-		catch( std::exception & ex )
-		{
-			throw ex;
-		}
+        try
+        {
+            Lifeobase::builder->get_widget( "vbox_login", m_vbox_login );
+            Menubutton::s_builder_name = "button_login_recent";
+            Lifeobase::builder->get_widget_derived( "button_login_recent", m_filebuttonrecent );
+            Lifeobase::builder->get_widget_derived( "entry_login_password", m_entry_password );
+            Lifeobase::builder->get_widget( "label_login_info", m_label_login_info );
+            Lifeobase::builder->get_widget( "image_login_about", image_about );
+            Lifeobase::builder->get_widget( "button_login_about", button_about );
+            Lifeobase::builder->get_widget( "button_login_open", m_button_open_diary );
+            Lifeobase::builder->get_widget( "button_login_quit", button_quit );
+        }
+        catch( ... )
+        {
+            throw LIFEO::Error( "creation of login  view failed" );
+        }
 
-		align1->set_padding( 110, 90, 30, 30 );
+        image_about->set( PIXMAPDIR "/lifeograph.png" );
+        m_entry_password->set_idle_text( "Password" );
+        m_filebuttonrecent->set( &m_settings.recentfiles );
 
-		m_table_login->set_spacings( 5 );
+        // SIGNALS
+        m_entry_password->signal_changed().connect(
+                sigc::mem_fun( *this, &Lifeograph::handle_entry_password_changed ) );
+        m_button_open_diary->signal_clicked().connect(
+                sigc::mem_fun( *this, &Lifeograph::handle_button_opendb_clicked ) );
+        button_quit->signal_clicked().connect(
+                sigc::mem_fun( *this, &Lifeograph::handle_button_quit_clicked ) );
+        button_about->signal_clicked().connect(
+                sigc::mem_fun( *this, &Lifeograph::handle_button_about_clicked ) );
 
-		m_button_opendiary->set_flags( Gtk::CAN_DEFAULT | Gtk::RECEIVES_DEFAULT );
-		
-		m_entry_password->set_visibility( false );
-		m_entry_password->set_activates_default( true );
+        m_filebuttonrecent->signal_selection_changed().connect(
+                sigc::mem_fun( *this, &Lifeograph::handle_filebutton_db_selectionchanged ) );
+        m_filebuttonrecent->signal_create_file().connect(
+                sigc::mem_fun( *this, &Lifeograph::initialize_new_diary ) );
 
-		m_label_startupmessage->set_line_wrap( true );
-		m_label_startupmessage->set_alignment( Gtk::ALIGN_CENTER );
+        // FILL RECENT FILES LIST
+        if( ! m_settings.recentfiles.empty() )
+            m_filebuttonrecent->update_filenames();
+    }
 
-		button_about->set_relief( Gtk::RELIEF_NONE );
-		button_about->set_focus_on_click( false );
-		button_quit->set_relief( Gtk::RELIEF_NONE );
-		button_quit->set_focus_on_click( false );
+    set_default( *m_button_open_diary );
 
-		// PACKING
-		hbox->pack_start( *button_about, Gtk::PACK_SHRINK, 5 );
-		hbox->pack_start( *button_quit, Gtk::PACK_SHRINK, 5 );
+    add( *m_vbox_login );
+    m_vbox_login->show_all();
 
-		m_table_login->attach( *label_diary, 0, 1, 0, 1,
-							Gtk::SHRINK | Gtk::FILL, Gtk::SHRINK );
-		m_table_login->attach( *label_password, 0, 1, 1, 2,
-							Gtk::SHRINK | Gtk::FILL, Gtk::SHRINK );
-
-		m_table_login->attach( *m_filebuttonrecent, 1, 2, 0, 1,
-							Gtk::EXPAND | Gtk::FILL, Gtk::SHRINK );
-		m_table_login->attach( *m_entry_password, 1, 2, 1, 2,
-							Gtk::EXPAND | Gtk::FILL, Gtk::SHRINK );
-
-		m_table_login->attach( *m_button_opendiary, 2, 3, 0, 2,
-							Gtk::SHRINK | Gtk::FILL, Gtk::SHRINK | Gtk::FILL );
-
-		m_table_login->attach( *hseparator, 0, 3, 2, 3,
-							Gtk::SHRINK | Gtk::FILL, Gtk::SHRINK );
-
-		m_table_login->attach( *m_label_startupmessage, 0, 3, 3, 4,
-							Gtk::EXPAND | Gtk::FILL, Gtk::SHRINK );
-
-		align1->add( *m_table_login );
-		align2->add( *hbox );
-
-		m_vbox_login->pack_start( *align1, Gtk::PACK_EXPAND_WIDGET, 5 );
-		m_vbox_login->pack_start( *align2, Gtk::PACK_SHRINK, 5 );
-
-		// SIGNALS
-		m_entry_password->signal_changed().connect(
-				sigc::mem_fun( *this, &Lifeograph::handle_entry_password_changed ) );
-		m_button_opendiary->signal_clicked().connect(
-				sigc::mem_fun( *this, &Lifeograph::handle_button_opendb_clicked ) );
-		button_quit->signal_clicked().connect(
-				sigc::mem_fun( *this, &Lifeograph::handle_button_quit_clicked ) );
-		button_about->signal_clicked().connect(
-				sigc::mem_fun( *this, &Lifeograph::handle_button_about_clicked ) );
-
-		
-		m_filebuttonrecent->signal_selection_changed().connect(
-				sigc::mem_fun( *this, &Lifeograph::handle_filebutton_db_selectionchanged ) );
-		m_filebuttonrecent->signal_create_file().connect(
-				sigc::mem_fun( *this, &Lifeograph::initialize_new_diary ) );
-
-		// FILL RECENT FILES LIST
-		if( ! m_settings.recentfiles.empty() )
-			m_filebuttonrecent->update_filenames();
-	}
-
-	set_default( *m_button_opendiary );
-
-	add( *m_vbox_login );
-	m_vbox_login->show_all();
-
-	// SETTING DB FILE
-	update_login_file();
-	set_title( PROGRAM_NAME );
+    // SETTING DB FILE
+    update_login_file();
+    set_title( PROGRAM_NAME );
 }
 
 void
@@ -943,43 +866,26 @@ Lifeograph::draw_editscreen( void )
 
 	if( m_hpaned_main == NULL )
 	{
-		Gtk::Toolbar				*toolbar_diary_prefs;
-		Menutoolbutton				*toolbutton_tools;
-		Gtk::ImageMenuItem			*menuitem_preferences;
-		Gtk::ImageMenuItem			*menuitem_about;
-		Gtk::SeparatorMenuItem		*menuitem_separator1;
-		Menu2						*menu_entry_list;
+        Gtk::MenuItem               *menuitem_preferences;
+        Gtk::MenuItem               *menuitem_about;
 
 		try
 		{
 			Lifeobase::builder->get_widget( "hpaned_main", m_hpaned_main );
 			// TOOLBAR AND ITS ITEMS
-			Lifeobase::builder->get_widget( "tbutton_today", m_toolbutton_today );
-			Lifeobase::builder->get_widget( "tbutton_logout", m_toolbutton_logout );
+			Lifeobase::builder->get_widget( "button_today", m_button_today );
+			Lifeobase::builder->get_widget( "button_logout", m_button_logout );
 
-			// TOOLS MENU
-			toolbutton_tools = Gtk::manage(
-					new Menutoolbutton( Gtk::Stock::PREFERENCES, _( "Tools" ) ) );
-			menuitem_preferences = Gtk::manage(
-					new Gtk::ImageMenuItem( Gtk::Stock::PREFERENCES ) );
-			menuitem_about = Gtk::manage( new Gtk::ImageMenuItem( Gtk::Stock::ABOUT ) );
-			menuitem_separator1 = Gtk::manage( new Gtk::SeparatorMenuItem );
+            Lifeobase::builder->get_widget( "menuitem_preferences", menuitem_preferences );
+            Lifeobase::builder->get_widget( "menuitem_about", menuitem_about );
 
-			// TIME BASED NAVIGATION PANE
-			Lifeobase::builder->get_widget( "toolbar_diary_prefs", toolbar_diary_prefs );
-
-			Lifeobase::builder->get_widget( "hpaned_second", m_hpaned_entry );
-			Lifeobase::builder->get_widget( "label_gui_elem", m_label_gui_elem );
-			Lifeobase::builder->get_widget( "label_gui_elem_extra", m_label_gui_elem_extra );
-			Lifeobase::builder->get_widget( "button_gui_elem", m_button_gui_elem );
-			Lifeobase::builder->get_widget( "image_gui_elem", m_image_gui_elem );
-			Lifeobase::builder->get_widget( "hbox_gelem_header", m_hbox_gelem_header );
-
-			Lifeobase::builder->get_widget_derived( "menu_entry_list", menu_entry_list );
-
-			m_menubutton_list = Gtk::manage(
-					new Menutoolbutton( Gtk::Stock::SORT_ASCENDING,
-										_( "List" ), menu_entry_list, false ) );
+            // TIME BASED NAVIGATION PANE
+            Lifeobase::builder->get_widget( "hpaned_second", m_hpaned_entry );
+            Lifeobase::builder->get_widget( "label_gui_elem", m_label_gui_elem );
+            Lifeobase::builder->get_widget( "label_gui_elem_extra", m_label_gui_elem_extra );
+            Lifeobase::builder->get_widget( "button_gui_elem", m_button_gui_elem );
+            Lifeobase::builder->get_widget( "image_gui_elem", m_image_gui_elem );
+            Lifeobase::builder->get_widget( "hbox_gelem_header", m_hbox_gelem_header );
 
 			m_panel_main = new PanelMain;
 			m_panel_diary = new PanelDiary;
@@ -999,23 +905,12 @@ Lifeograph::draw_editscreen( void )
 			throw ex;
 		}
 
-		// SORT-BY MENU ITEMS
-		toolbar_diary_prefs->insert( *m_menubutton_list, 2 );
-		m_menubutton_list->show_all();
-
-		// TOOLS MENU ITEMS
-		toolbar_diary_prefs->insert( *toolbutton_tools, 3 );
-		toolbutton_tools->get_menu()->attach( *menuitem_preferences, 0, 1, 0, 1 );
-		toolbutton_tools->get_menu()->attach( *menuitem_separator1, 0, 1, 1, 2 );
-		toolbutton_tools->get_menu()->attach( *menuitem_about, 0, 1, 2, 3 );
-		toolbutton_tools->get_menu()->show_all_children();
-		toolbutton_tools->show_all();
-
-		m_hpaned_main->set_position( m_settings.position_pane );
-		m_hpaned_entry->set_position( m_settings.position_pane_tags );
+        // GEOMETRY
+        m_hpaned_main->set_position( m_settings.position_pane );
+        m_hpaned_entry->set_position( m_settings.position_pane_tags );
 
 		// ACTIONS
-		m_action_today->connect_proxy( *m_toolbutton_today );
+		m_action_today->connect_proxy( *m_button_today );
 		m_action_previous_browsing->connect_proxy( *m_button_gui_elem );
 		m_action_previous_match->connect_proxy( *m_panel_diary->m_button_match_prev );
 		m_action_next_match->connect_proxy( *m_panel_diary->m_button_match_next );
@@ -1023,20 +918,13 @@ Lifeograph::draw_editscreen( void )
 		m_panel_diary->m_button_match_prev->set_visible( false );
 		m_panel_diary->m_button_match_next->set_visible( false );
 
-		m_toolbutton_logout->add_accelerator(
+		m_button_logout->add_accelerator(
 				"clicked",
 				get_accel_group(),
 				GDK_Escape,
 				Gdk::CONTROL_MASK,
 				Gtk::ACCEL_VISIBLE );
 
-		menuitem_preferences->add_accelerator(
-				"activate",
-				get_accel_group(),
-				GDK_F10,
-				Gdk::ModifierType( 0 ),
-				Gtk::ACCEL_VISIBLE );
-
 		// SIGNALS
 		m_action_today->signal_activate().connect(
 				sigc::mem_fun( *this, &Lifeograph::show_today ) );
@@ -1046,7 +934,7 @@ Lifeograph::draw_editscreen( void )
 		menuitem_preferences->signal_activate().connect(
 				sigc::ptr_fun( &DialogPreferences::create ) );
 
-		m_toolbutton_logout->signal_clicked().connect(
+		m_button_logout->signal_clicked().connect(
 				sigc::bind( sigc::mem_fun( *this, &Lifeograph::logout ), true ) );
 
 		LinkEntry::signal_activated().connect(
@@ -1071,7 +959,7 @@ Lifeograph::draw_editscreen( void )
 
 	m_panel_diary->handle_login();
 	m_panel_tag->populate_main();
-	m_panel_tag->m_button_remove_filter->set_visible( false );
+	m_panel_diary->m_button_remove_filters->set_visible( false );
 	m_widget_panel_exp->populate_themes();
 	m_tag_view->update_combobox_categories();
 	m_diary_view->handle_login();
@@ -1107,9 +995,9 @@ Lifeograph::create_actions( void )
 					_( "Previous" ),
 					_( "Go to the previous entry in the list" ),
 					Gtk::AccelKey( GDK_Page_Up, Gdk::CONTROL_MASK ),
-					sigc::bind(
-						sigc::mem_fun( m_panel_diary, &PanelDiary::go_up ),
-						false ) );
+                    sigc::bind( sigc::mem_fun( m_panel_diary->m_treeview_entries,
+                                               &WidgetEntryList::go_up ),
+                                false ) );
 
 	create_action(	m_action_next_list,
 					"ListNext",
@@ -1117,9 +1005,9 @@ Lifeograph::create_actions( void )
 					_( "Next" ),
 					_( "Go to the next entry in the list" ),
 					Gtk::AccelKey( GDK_Page_Down, Gdk::CONTROL_MASK ),
-					sigc::bind(
-						sigc::mem_fun( m_panel_diary, &PanelDiary::go_down ),
-						false ) );
+                    sigc::bind( sigc::mem_fun( m_panel_diary->m_treeview_entries,
+                                               &WidgetEntryList::go_down ),
+                                false ) );
 
 	create_action(	m_action_previous_browsing,
 					"BrowseBack",
