@@ -79,7 +79,7 @@ namespace LIFEO
 											"Please select anoter file..." );
 
 		const char      DB_IS_NOT_ENCRYPTED[]
-                                    = N_(	"Unencrypted diary. Press OK to open" );
+                                    = N_(	"Press Open to continue" );
 
 		const char      SALUTATION[]    /*  TRANSLATORS: this is the message
                                             shown to the fist time users */
@@ -109,7 +109,7 @@ class Lifeograph : public Lifeobase
 							Lifeograph( int, char** );
 							~Lifeograph ();
 
-		void				run( void );
+		void                on_run( void );
 
 		void				draw_welcomescreen( void );
 		void				draw_loginscreen( void );
@@ -124,8 +124,9 @@ class Lifeograph : public Lifeobase
 		void				update_entry_list();
 		void				update_tag_list( void );
 		void				update_tag_categories( void );
-		void				update_filter_tag( void );
-		void				update_tag_icon( Tag* );
+		void				update_button_filter_tag( void );
+		void				update_button_remove_filters( void );
+		void				update_tag_icon( const Tag* );
 		void				update_theme_list( void );
 		void				update_entryliststyle( void );
 		void				update_calendar( void );
@@ -144,6 +145,8 @@ class Lifeograph : public Lifeobase
 		void				focus_filter( void );
 		void				focus_tag( void );
 
+		void                toggle_comments( void );
+
 		void				initialize_new_diary( void );
 		bool				write_backup( void );
 		bool				finish_editing( bool = true );
@@ -169,18 +172,14 @@ class Lifeograph : public Lifeobase
 
 	protected:
 		bool				on_delete_event( GdkEventAny* );
-		bool				on_expose_event( GdkEventExpose* );
 		bool				on_event( GdkEvent* );
 
 		// WIDGETS
 		Gtk::AboutDialog			*m_about_dialog;
-		Gtk::Table					*m_table_login;
-		Gtk::Label					*m_label_startupmessage;
+		Gtk::Label					*m_label_login_info;
 		FilebuttonRecent			*m_filebuttonrecent;
-		Gtk::Entry					*m_entry_password;
-		Gtk::Button					*m_button_opendiary;
-
-		Menutoolbutton				*m_menubutton_list;
+        EntryIdletext				*m_entry_password;
+		Gtk::Button					*m_button_open_diary;
 
 		Gtk::Menu					*m_menu_link;
 		PanelMain					*m_panel_main;
@@ -192,8 +191,8 @@ class Lifeograph : public Lifeobase
 		Gtk::HPaned					*m_hpaned_entry;
 		Gtk::HPaned					*m_hpaned_main;
 
-		Gtk::ToolButton				*m_toolbutton_today;
-		Gtk::ToolButton				*m_toolbutton_logout;
+        Gtk::Button                 *m_button_today;
+        Gtk::Button                 *m_button_logout;
 
 		sigc::connection			m_connection_backup;
 
@@ -223,6 +222,8 @@ class Lifeograph : public Lifeobase
 		LoginStatus					m_loginstatus;
 		bool						m_flag_firsttimeuser;
 		bool						m_flag_ignore_locks;
+        bool                        m_flag_open_directly;
+        bool                        m_flag_force_welcome;
 };
 
 } // end of namespace LIFEO
