@@ -57,7 +57,7 @@ main( int argc, char *argv[] )
 
 	LIFEO::Lifeograph *lifeograph = new LIFEO::Lifeograph( argc, argv );
 
-	lifeograph->run();
+    Gtk::Main::run( *lifeograph );
 
 	delete lifeograph;
 
