@@ -38,19 +38,32 @@ PanelDiary::PanelDiary( void )
 {
 	try
 	{
+        Menubutton *mb_tools, *mb_add;
+
+        Menubutton::s_builder_name = "menubutton_tools";
+        Lifeobase::builder->get_widget_derived( Menubutton::s_builder_name, mb_tools );
+        Lifeobase::builder->get_widget( "menuitem_sort_by_date", m_menuitem_sort_by_date );
+        Lifeobase::builder->get_widget( "menuitem_sort_by_size", m_menuitem_sort_by_size );
+
+        Lifeobase::builder->get_widget( "togglebtn_filter_favorites",
+                                        m_togglebtn_filter_favorites );
+        Lifeobase::builder->get_widget( "button_remove_filters", m_button_remove_filters );
+
 		Lifeobase::builder->get_widget( "calendar_main", m_calendar );
 		Lifeobase::builder->get_widget_derived( "treeview_main", m_treeview_entries );
 		Lifeobase::builder->get_widget_derived( "entry_filter", m_entry_filter );
 		Lifeobase::builder->get_widget_derived( "entry_replace", m_entry_replace );
-		Lifeobase::builder->get_widget( "tbutton_match_prev", m_button_match_prev );
-		Lifeobase::builder->get_widget( "tbutton_match_next", m_button_match_next );
-		Lifeobase::builder->get_widget( "tbutton_replace", m_toolbutton_replace );
-		Lifeobase::builder->get_widget( "tbutton_replace_all", m_toolbutton_replace_all );
-		Lifeobase::builder->get_widget( "toolbar_replace", m_toolbar_replace );
+		Lifeobase::builder->get_widget( "button_match_prev", m_button_match_prev );
+		Lifeobase::builder->get_widget( "button_match_next", m_button_match_next );
+		Lifeobase::builder->get_widget( "button_replace", m_button_replace );
+		Lifeobase::builder->get_widget( "button_replace_all", m_button_replace_all );
+		Lifeobase::builder->get_widget( "hbox_toolbar_replace", m_toolbar_replace );
 
-		Lifeobase::builder->get_widget( "menuitem_sort_by_date", m_menuitem_sort_by_date );
-		Lifeobase::builder->get_widget( "menuitem_sort_by_size", m_menuitem_sort_by_size );
-		Lifeobase::builder->get_widget( "menuitem_filter_favorites", m_menuitem_filter_favorites );
+        Menubutton::s_builder_name = "menubutton_diary_add";
+        Lifeobase::builder->get_widget_derived( Menubutton::s_builder_name, mb_add );
+        Lifeobase::builder->get_widget( "mnitem_add_entry", m_menuitem_add_entry );
+        Lifeobase::builder->get_widget( "mnitem_add_chapter", m_menuitem_add_chapter );
+        Lifeobase::builder->get_widget( "mnitem_add_topic", m_menuitem_add_topic );
 	}
 	catch( ... ) { }
 
@@ -59,14 +72,28 @@ PanelDiary::PanelDiary( void )
 	m_entry_replace->set_idle_text( _( "Replace" ) );
 
 	// SIGNALS
+    m_menuitem_sort_by_date->signal_activate().connect(
+            sigc::bind(
+                    sigc::mem_fun( m_treeview_entries,
+                                   &WidgetEntryList::handle_sorting_criteria_changed ),
+                    SC_DATE ) );
+    m_menuitem_sort_by_size->signal_activate().connect(
+            sigc::bind(
+                    sigc::mem_fun( m_treeview_entries,
+                                   &WidgetEntryList::handle_sorting_criteria_changed ),
+                    SC_SIZE ) );
+    m_togglebtn_filter_favorites->signal_toggled().connect(
+            sigc::mem_fun( this, &PanelDiary::handle_filter_favorites_toggled ) );
+
+    m_button_remove_filters->signal_clicked().connect(
+            sigc::mem_fun( this, &PanelDiary::remove_filters ) );
+
 	m_calendar->signal_day_selected_double_click().connect(
-			sigc::mem_fun( this, &PanelDiary::handle_calendar_doubleclicked ) );
+			sigc::mem_fun( this, &PanelDiary::handle_add_entry ) );
 	m_calendar->signal_month_changed().connect(
 			sigc::mem_fun( this, &PanelDiary::handle_calendar_monthchanged ) );
 	m_calendar->signal_day_selected().connect(
 			sigc::mem_fun( this, &PanelDiary::handle_calendar_dayselected ) );
-	m_calendar->signal_button_press_event().connect_notify(
-			sigc::mem_fun( this, &PanelDiary::handle_calendar_button_pressed ) );
 
 	m_entry_filter->signal_changed().connect(
 			sigc::mem_fun( this, &PanelDiary::handle_entry_filter_changed ) );
@@ -75,9 +102,9 @@ PanelDiary::PanelDiary( void )
 
 	m_entry_replace->signal_activate().connect(
 			sigc::mem_fun( this, &PanelDiary::replace_match ) );
-	m_toolbutton_replace->signal_clicked().connect(
+	m_button_replace->signal_clicked().connect(
 			sigc::mem_fun( this, &PanelDiary::replace_match ) );
-	m_toolbutton_replace_all->signal_clicked().connect(
+	m_button_replace_all->signal_clicked().connect(
 			sigc::mem_fun( this, &PanelDiary::replace_all_matches ) );
 
 	m_treeview_entries->signal_row_expanded().connect(
@@ -85,18 +112,12 @@ PanelDiary::PanelDiary( void )
 	m_treeview_entries->signal_row_collapsed().connect(
 			sigc::mem_fun( this, &PanelDiary::handle_treeview_row_expanded ) );
 
-	m_menuitem_sort_by_date->signal_activate().connect(
-			sigc::bind(
-					sigc::mem_fun( m_treeview_entries,
-								   &WidgetEntryList::handle_sorting_criteria_changed ),
-					SC_DATE ) );
-	m_menuitem_sort_by_size->signal_activate().connect(
-			sigc::bind(
-					sigc::mem_fun( m_treeview_entries,
-								   &WidgetEntryList::handle_sorting_criteria_changed ),
-					SC_SIZE ) );
-	m_menuitem_filter_favorites->signal_activate().connect(
-			sigc::mem_fun( this, &PanelDiary::handle_filter_favorites_toggled ) );
+    m_menuitem_add_entry->signal_activate().connect(
+            sigc::mem_fun( this, &PanelDiary::handle_add_entry ) );
+    m_menuitem_add_topic->signal_activate().connect(
+            sigc::mem_fun( this, &PanelDiary::handle_add_topic ) );
+    m_menuitem_add_chapter->signal_activate().connect(
+            sigc::mem_fun( this, &PanelDiary::handle_add_chapter ) );
 }
 
 void
@@ -187,9 +208,7 @@ PanelDiary::update_entry_list( void )
 		add_chapter_category_to_list( Diary::d->get_current_chapter_ctg() );
 	}
 
-	for( ;
-		 l_itr_entry != Diary::d->m_entries.end();
-		 ++l_itr_entry )
+    for( ; l_itr_entry != Diary::d->m_entries.end(); ++l_itr_entry )
 	{
 		l_entry = ( *l_itr_entry ).second;
 		if( l_entry->get_filtered_out() == false )
@@ -223,7 +242,11 @@ PanelDiary::update_entry_list( void )
 			flag_show_elem = false;
 	}
 	else	// the case at the start-up
+	{
 		elem = Diary::d->get_startup_elem();
+		if( elem == NULL )	// if last item was empty and dismissed at logout
+			elem = Diary::d;
+	}
 
 	if( flag_show_elem )
 		elem->show();
@@ -288,8 +311,12 @@ PanelDiary::handle_logout( void )
 {
 	m_entry_filter->set_text( "" );
 	m_entry_replace->set_text( "" );
-	m_menuitem_filter_favorites->set_active( false );
+	m_togglebtn_filter_favorites->set_active( false );
 	m_treeview_entries->m_treestore_entries->clear();
+
+    m_button_match_prev->hide();
+    m_button_match_next->hide();
+    m_toolbar_replace->hide();
 }
 
 void
@@ -300,10 +327,20 @@ PanelDiary::show( const DiaryElement *element )
 	else
 		m_treeview_entries->get_selection()->unselect_all();
 
-	if( element->get_type() > DiaryElement::IT_DIARY )
-		select_date_in_calendar( element->get_date() );
+	if( element->get_type() > DiaryElement::IT_DIARY && ! element->get_date().is_ordinal() )
+    {
+        select_date_in_calendar( element->get_date() );
+        m_menuitem_add_entry->set_sensitive( true );
+        m_menuitem_add_chapter->set_sensitive(
+                Diary::d->get_current_chapter_ctg()->get_chapter( element->get_date() )
+                == NULL );
+    }
 	else
-		m_calendar->select_day( 0 );
+	{
+        m_calendar->select_day( 0 );
+        m_menuitem_add_entry->set_sensitive( false );
+        m_menuitem_add_chapter->set_sensitive( false );
+	}
 }
 
 void
@@ -344,7 +381,7 @@ PanelDiary::handle_entry_filter_changed( void )
 	{
 		if( Lifeobase::m_entrycount > 0 )
 		{
-			TextviewDiary::m_buffer->set_searchstr( filterstring );
+			TextviewDiary::m_buffer->set_search_str( filterstring );
 			if( Lifeobase::base->get_cur_elem_type() == DiaryElement::IT_ENTRY )
 				TextviewDiary::m_buffer->select_searchstr_next();
 		}
@@ -356,7 +393,7 @@ PanelDiary::handle_entry_filter_changed( void )
 	}
 	else
 	{
-		TextviewDiary::m_buffer->set_searchstr( "" );
+		TextviewDiary::m_buffer->set_search_str( "" );
 		m_entry_filter->set_tooltip_text( _( "Enter text to be filtered" ) );
 	}
 
@@ -385,131 +422,24 @@ PanelDiary::handle_filter_favorites_toggled( void )
 	update_entry_list();					// apply the filter
 }
 
-inline bool
-PanelDiary::make_path_deeper_last( Gtk::TreePath &path )
-{
-	if( ! m_treeview_entries->m_treemodelsort_entries->
-					get_iter( path )->children().empty() )
-	{
-		path.push_back( m_treeview_entries->m_treemodelsort_entries->
-				get_iter( path )->children().size() - 1 );
-		return true;
-	}
-	return false;
-}
-
-inline bool
-PanelDiary::move_path_next( Gtk::TreePath &path )
-{
-	if( unsigned( path.back() ) < ( m_treeview_entries->m_treemodelsort_entries->
-				get_iter( path )->parent()->children().size() - 1 ) )
-	{
-		path.next();
-		return true;
-	}
-	else
-		return false;
-}
-
 void
-PanelDiary::go_up( bool flag_entry_operation )
+PanelDiary::remove_filters( void )
 {
-	// flag_entry: if true, goes to an entry item even when the current...
-	// ...item is a folder
-	Gtk::TreeIter iter( m_treeview_entries->get_selection()->get_selected() );
-	if( iter == m_treeview_entries->m_treemodelsort_entries->children().end() )
-		return;
-	Gtk::TreePath path( m_treeview_entries->m_treemodelsort_entries->get_path( iter ) );
-	DiaryElement *elem;
+    if( Diary::d->get_filtering_status() & ( Diary::FS_FILTER_DATE | Diary::FS_FILTER_TAG) )
+    {
+        const Tag *tag( Diary::d->get_filter_tag() );
+        if( tag != NULL )
+        {
+            Diary::d->set_filter_tag( NULL );
+            Lifeobase::base->update_tag_icon( tag );
+            Lifeobase::base->update_button_filter_tag();
+        }
+        m_button_remove_filters->set_visible( false );
 
-	do
-	{
-		if( ! path.prev() )
-		{
-			if( path.size() > 1 )
-				path.up();
-			else	// diary
-			if( make_path_deeper_last( path ) )
-				make_path_deeper_last( path ); // go still deeper if possible:
-		}
-		else
-			make_path_deeper_last( path );
+        Diary::d->clear_filter_date();
 
-		elem = ( * m_treeview_entries->m_treemodelsort_entries->
-						get_iter( path ) )[ ListData::colrec->ptr ];
-	}
-	// repeat until an entry is found if that is what we are looking for
-	// BEWARE: do not set this flag when there is no entry in the list
-	while( flag_entry_operation && elem->get_type() != DiaryElement::IT_ENTRY );
-
-	PRINT_DEBUG( "previous path: " + path.to_string() );
-
-	Gtk::TreeRow row = * m_treeview_entries->m_treemodelsort_entries->get_iter( path );
-	DiaryElement *element( row[ ListData::colrec->ptr ] );
-	element->show();
-}
-
-void
-PanelDiary::go_down( bool flag_entry_operation )
-{
-	// flag_entry: if true, goes to an entry item even when the current...
-	// ...item is a folder
-	Gtk::TreeIter iter( m_treeview_entries->get_selection()->get_selected() );
-	if( iter == m_treeview_entries->m_treemodelsort_entries->children().end() )
-		return;
-	Gtk::TreePath path( m_treeview_entries->m_treemodelsort_entries->get_path( iter ) );
-	DiaryElement *elem;
-
-	do
-	{
-		if( ! m_treeview_entries->m_treemodelsort_entries->
-					get_iter( path )->children().empty() )
-			path.down();
-		else
-		if( ! move_path_next( path ) )
-		{
-			while( path.size() > 1 )
-			{
-				path.up();
-				if( move_path_next( path ) )
-					break;
-			}
-		}
-
-		elem = ( * m_treeview_entries->m_treemodelsort_entries->
-						get_iter( path ) )[ ListData::colrec->ptr ];
-	}
-	// repeat until an entry is found if that is what we are looking for
-	// BEWARE: do not set this flag when there is no entry in the list
-	while( flag_entry_operation && elem->get_type() != DiaryElement::IT_ENTRY );
-
-	PRINT_DEBUG( "next path: " + path.to_string() );
-
-	Gtk::TreeRow row = * m_treeview_entries->m_treemodelsort_entries->get_iter( path );
-	DiaryElement *listitem = row[ ListData::colrec->ptr ];
-	listitem->show();
-}
-
-void
-PanelDiary::handle_calendar_doubleclicked( void )
-{
-	guint year, month, day;
-
-	m_calendar->get_date( year, month, day );
-
-	Entry *entry = Diary::d->create_entry( Date( year, month + 1, day ) );
-
-	// FIXME: replace these with more direct functions like add_entry()
-	// (after treeview becomes a class of its own)
-	update_entry_list();
-	update_calendar();
-
-	entry->show();
-
-	// this is the only way i could find to give focus to textview
-	//FIXME
-//	Glib::signal_timeout().connect_once(
-//			sigc::mem_fun( m_textviewdiary, &Gtk::Widget::grab_focus ), 200 );
+        update_entry_list();
+    }
 }
 
 void
@@ -520,15 +450,20 @@ PanelDiary::handle_calendar_dayselected( void )
 	guint year, month, day;
 	m_calendar->get_date( year, month, day );
 	Date date( year, month + 1, day );
+
+    m_menuitem_add_entry->set_sensitive( day > 0 );
+    m_menuitem_add_chapter->set_sensitive( day > 0 &&
+            Diary::d->get_current_chapter_ctg()->get_chapter( date ) == NULL );
+
 	Entry *entry;
-	if( date.get_pure() == ( Lifeobase::base->get_cur_elem()->get_date().get_pure() ) )
+	if( date.m_date == ( Lifeobase::base->get_cur_elem()->get_date().get_pure() ) )
 	{
-		//date = m_panel_main->get_cur_elem()->get_date();
-		entry = Diary::d->get_entry_nextinday( date );
+        entry = Diary::d->get_entry_next_in_day(
+                Lifeobase::base->get_cur_elem()->get_date() );
 	}
 	else
 	{
-		entry = Diary::d->get_entry( date );
+        entry = Diary::d->get_entry( date.m_date + 1 ); // 1 increment to fix order
 	}
 
 	if( entry )
@@ -538,62 +473,56 @@ PanelDiary::handle_calendar_dayselected( void )
 void
 PanelDiary::handle_calendar_monthchanged( void )
 {
-	if( Lifeobase::m_internaloperation ) return;
+    if( Lifeobase::m_internaloperation ) return;
 
 	update_calendar();
 }
 
 void
-PanelDiary::create_chapter( const Date &date )
+PanelDiary::handle_add_entry( void )
 {
-	// CAUTION: nohing is checked here as everything should have been checked before
+    guint year, month, day;
+    m_calendar->get_date( year, month, day );
 
-	Chapter *c = Diary::d->get_current_chapter_ctg()->create_chapter(
-			_( "Untitled chapter" ), date );
+    if( day )
+    {
+        Entry *entry( Diary::d->create_entry( Date( year, month + 1, day ) ) );
 
-	Lifeobase::base->update_entry_list();
-	c->show();
+        update_entry_list();
+        update_calendar();
+
+        entry->show();
+    }
+
+    // this is the only way i could find to give focus to textview
+    //FIXME
+//  Glib::signal_timeout().connect_once(
+//          sigc::mem_fun( m_textviewdiary, &Gtk::Widget::grab_focus ), 200 );
 }
 
 void
-PanelDiary::handle_calendar_button_pressed( GdkEventButton *event )
+PanelDiary::handle_add_topic( void )
 {
-	if( event->button != 3 )
-		return;
+    Chapter *c( Diary::d->add_topic( _( "New topic" ) ) );
+    Lifeobase::base->update_entry_list();
+    c->show();
+}
 
-	static Gtk::Menu *m_menu( NULL );
+void
+PanelDiary::handle_add_chapter( void )
+{
+    guint year, month, day;
+    m_calendar->get_date( year, month, day );
+    Date date( year, month + 1, day );
 
-	if( m_menu )
-	{
-		delete m_menu;
-		m_menu = NULL;
-	}
+    if( day > 0 && Diary::d->get_current_chapter_ctg()->get_chapter( date ) == NULL )
+    {
+        Chapter *c( Diary::d->get_current_chapter_ctg()->create_chapter(
+                _( "Untitled chapter" ), date ) );
 
-	m_menu = new Gtk::Menu;
-
-	m_menu->items().push_back(
-			Gtk::Menu_Helpers::MenuElem( _( "Create an _Entry" ),
-			sigc::mem_fun( this, &PanelDiary::handle_calendar_doubleclicked ) ) );
-
-	CategoryChapters *cc = Diary::d->get_current_chapter_ctg();
-	if( cc != NULL )
-	{
-		guint year, month, day;
-		m_calendar->get_date( year, month, day );
-		Date date_selected( year, month + 1, day );
-		if( cc->get_chapter( date_selected ) == NULL )
-		{
-			m_menu->items().push_back(
-					Gtk::Menu_Helpers::MenuElem( _( "Create a _Chapter" ),
-					sigc::bind( sigc::mem_fun( this, &PanelDiary::create_chapter ),
-								date_selected ) ) );
-		}
-	}
-
-	m_menu->accelerate( *m_calendar );
-	m_menu->popup( event->button, event->time );
-
-	return;
+        Lifeobase::base->update_entry_list();
+        c->show();
+    }
 }
 
 void
@@ -629,7 +558,7 @@ PanelDiary::go_prev_match( void )
 	int i = 0;
 	do
 	{
-		go_up( true );
+        m_treeview_entries->go_up( true );
 		// put cursor to the end:
 		TextviewDiary::m_buffer->select_range( TextviewDiary::m_buffer->end(),
 											   TextviewDiary::m_buffer->end() );
@@ -653,7 +582,7 @@ PanelDiary::go_next_match( void )
 	int i = 0;
 	do
 	{
-		go_down( true );
+        m_treeview_entries->go_down( true );
 		i++;
 	}
 	while( ! TextviewDiary::m_buffer->select_searchstr_next() &&
