@@ -46,7 +46,7 @@ Settings::read( void )
 
 	if( ! file.is_open() )
 	{
-		print_error( "failed to open configuration file: " + path );
+		print_info( "No configuration file, maiden voyage!" );
 		return false;
 	}
 	
@@ -91,9 +91,6 @@ Settings::read( void )
 				if( idletime < IDLETIME_MIN || idletime > IDLETIME_MAX )
 					idletime = IDLETIME_DEFAULT;
 				break;
-			case 'B':
-				background = line.substr( 2 );
-				break;
 			case 'F':
 				show_formatting_toolbar = ( line[ 2 ] == 'y' || line[ 2 ] == 'Y' );
 				break;
@@ -102,7 +99,7 @@ Settings::read( void )
 			case '#':	// comment
 				break;
 			default:
-				print_error( "unrecognized line:\n" + line );
+				print_info( "unrecognized line:\n" + line );
 				break;
 		}
 	}
@@ -135,7 +132,6 @@ Settings::write( void )
 
 	file << "\nL " << ( autologout ? 'y' : 'n' );
 	file << "\nI " << idletime;
-	file << "\nB " << background;
 	file << "\nF " << ( show_formatting_toolbar ? 'y' : 'n' );
 
 	file.close();
