@@ -80,6 +80,7 @@ class Undoable {
 class UndoManager {
 	public:
 									UndoManager( void );
+
 		void						add_action( Undoable* );
 		void						clear( void );
 
@@ -110,6 +111,9 @@ class UndoManager {
 			m_freezed = false;
 		}
 
+		// GLOBAL UNDO MANAGER
+		static UndoManager			*m;
+
 	protected:
 
 	private:
