@@ -25,22 +25,31 @@
 #endif
 
 #include "view_entry.hpp"
+#include "printing.hpp"
 
 
 using namespace LIFEO;
 
 
 EntryView::EntryView( void )
-:	m_menu_tag( NULL ),
-	m_tag_operation_cur( TO_NONE ),
-	m_ptr2entry( NULL ),
+:	m_menu_tag( NULL ), m_tag_operation_cur( TO_NONE ), m_ptr2entry( NULL ),
 	m_flag_entrychanged( false )
 {
 	Entry::shower = this;
+	Menubutton *mnbutton_filter( NULL );
+	Gtk::MenuItem *mnitem_hide( NULL );
+	Gtk::MenuItem *mnitem_hide_before( NULL );
+	Gtk::MenuItem *mnitem_hide_after( NULL );
 
 	try
 	{
 		Lifeobase::builder->get_widget( "vbox_entry", m_vbox_entry );
+        Menubutton::s_builder_name = "menubutton_entry_filter";
+        Lifeobase::builder->get_widget_derived( "menubutton_entry_filter", mnbutton_filter );
+        Lifeobase::builder->get_widget( "menuitem_entry_filter", mnitem_hide );
+        Lifeobase::builder->get_widget( "menuitem_entry_filter_before", mnitem_hide_before );
+        Lifeobase::builder->get_widget( "menuitem_entry_filter_after", mnitem_hide_after );
+		Lifeobase::builder->get_widget( "button_entry_print", m_button_print );
 		Lifeobase::builder->get_widget( "togglebutton_entry_favorite", m_button_toggle_favorite );
 		Lifeobase::builder->get_widget( "button_entry_reset_theme", m_button_reset_theme );
 		Lifeobase::builder->get_widget( "button_entry_dismiss", m_button_dismiss );
@@ -52,12 +61,13 @@ EntryView::EntryView( void )
 		Lifeobase::builder->get_widget( "evntb_entry_highlight", m_eventbox_highlight );
 		Lifeobase::builder->get_widget( "button_entry_add_bullet", m_button_add_bullet );
 		Lifeobase::builder->get_widget( "button_entry_add_checkbox", m_button_add_checkbox );
+        Lifeobase::builder->get_widget( "tgglbutton_entry_comments", m_button_toggle_comments );
 		Lifeobase::builder->get_widget_derived( "textview_entry", m_textviewdiary );
 		Lifeobase::builder->get_widget_derived( "entry_tag_filter", m_tag_widget );
 		Lifeobase::builder->get_widget( "button_tag_operation", m_button_tag_operation );
 		Lifeobase::builder->get_widget( "iconview_current_tags", m_iconview_tags );
 		Lifeobase::builder->get_widget( "alignment_entry_toolbar", m_alignment_toolbar );
-		Lifeobase::builder->get_widget( "hbox_entry_2nd_toolbar", m_hbox_editing_toolbar );
+		Lifeobase::builder->get_widget( "hbox_entry_toolbar_text", m_hbox_editing_toolbar );
 	}
 	catch( ... ) {}
 
@@ -92,6 +102,13 @@ EntryView::EntryView( void )
 			sigc::mem_fun( this, &LIFEO::EntryView::reset_theme ) );
 	m_button_toggle_favorite->signal_toggled().connect(
 			sigc::mem_fun( this, &LIFEO::EntryView::toggle_favoredness ) );
+	m_button_print->signal_clicked().connect(
+	        sigc::mem_fun( this, &EntryView::print ) );
+    mnitem_hide->signal_activate().connect( sigc::mem_fun( this, &EntryView::hide ) );
+    mnitem_hide_before->signal_activate().connect(
+            sigc::mem_fun( this, &EntryView::hide_before ) );
+    mnitem_hide_after->signal_activate().connect(
+            sigc::mem_fun( this, &EntryView::hide_after ) );
 
 	m_button_bold->signal_clicked().connect(
 			sigc::mem_fun( m_textviewdiary->m_buffer, &TextbufferDiary::toggle_bold ) );
@@ -107,6 +124,9 @@ EntryView::EntryView( void )
 	m_button_add_checkbox->signal_clicked().connect(
 			sigc::mem_fun( m_textviewdiary->m_buffer, &TextbufferDiary::add_checkbox ) );
 
+    m_button_toggle_comments->signal_clicked().connect(
+            sigc::mem_fun( this, &EntryView::toggle_comments ) );
+
 	m_textviewdiary->signal_drag_data_received().connect(
 			sigc::mem_fun( this, &EntryView::handle_drag_data_received ) );
 
@@ -138,7 +158,7 @@ EntryView::populate_tags( void )
 	if( ptr2tagset.size() < 1 )
 	{
 		row = * m_liststore_tags->append();
-		row[ TagPanel::colrec->name ] = Glib::ustring::compose( "<i>%1</i>", _( "None" ) );
+		row[ TagPanel::colrec->name ] = Glib::ustring::compose( "<i>%1</i>", _( "Not tagged" ) );
 		row[ TagPanel::colrec->ptr ] = NULL;
 		return;
 	}
@@ -265,7 +285,8 @@ EntryView::handle_drag_data_received(
 		{
 			DiaryElement *element = Lifeobase::base->get_dragged_elem();
 			if( element != NULL )
-				TextviewDiary::m_buffer->insert_link( element );
+                if( element->get_type() == DiaryElement::IT_ENTRY )
+                    TextviewDiary::m_buffer->insert_link( element );
 			break;
 		}
 	}
@@ -282,6 +303,52 @@ EntryView::toggle_favoredness( void )
 	row[ ListData::colrec->icon ] = m_ptr2entry->get_icon();
 }
 
+void
+EntryView::print( void )
+{
+    Lifeobase::base->sync_entry();
+
+    Glib::RefPtr< PrintOpr > print = PrintOpr::create();
+
+    try
+    {
+        print->set_show_comments( m_button_toggle_comments->get_active() );
+        print->run( Gtk::PRINT_OPERATION_ACTION_PRINT_DIALOG, *Lifeobase::base );
+    }
+    catch( const Gtk::PrintError &ex )
+    {
+        // See documentation for exact Gtk::PrintError error codes:
+        print_error( "An error occurred while trying to run a print operation:" +
+                ex.what() );
+    }
+}
+
+void
+EntryView::hide( void )
+{
+    m_ptr2entry->m_flag_filteredout = true;
+    Diary::d->activate_individual_filter();
+    Lifeobase::base->update_button_remove_filters();
+    Lifeobase::base->update_entry_list();
+}
+
+
+void
+EntryView::hide_before( void )
+{
+    Diary::d->set_filter_date_begin( m_ptr2entry->get_date().m_date );
+    Lifeobase::base->update_button_remove_filters();
+    Lifeobase::base->update_entry_list();
+}
+
+void
+EntryView::hide_after( void )
+{
+    Diary::d->set_filter_date_end( m_ptr2entry->get_date().m_date );
+    Lifeobase::base->update_button_remove_filters();
+    Lifeobase::base->update_entry_list();
+}
+
 void
 EntryView::reset_theme( void )
 {
@@ -309,6 +376,12 @@ EntryView::dismiss_entry( void )
 	Lifeobase::m_internaloperation--;
 }
 
+void
+EntryView::toggle_comments( void )
+{
+    m_textviewdiary->m_buffer->show_comments( m_button_toggle_comments->get_active() );
+}
+
 void
 EntryView::handle_entry_tag_changed( void )
 {
@@ -457,7 +530,7 @@ EntryView::show( Entry &entry )
 
 	Lifeobase::m_internaloperation++;
 	// BODY
-	TextviewDiary::m_buffer->set_richtext( &entry );
+	m_textviewdiary->set_richtext( &entry );
 	populate_tags();
 	m_button_toggle_favorite->set_active( entry.m_option_favored );
 	m_button_reset_theme->set_visible( entry.get_theme_is_set() );
