@@ -34,7 +34,7 @@
 namespace LIFEO
 {
 
-class EntryView : public Entry::Shower
+class EntryView : public ElementShower< Entry >
 {
 								EntryView( void );
 
@@ -55,8 +55,14 @@ class EntryView : public Entry::Shower
 		void					populate_tags( void );
 		void					remove_selected_tags( void );
 		void					dismiss_entry( void );
+		void                    print( void );
 		void					toggle_favoredness( void );
 		void					reset_theme( void );
+        void                    hide( void );
+        void                    hide_before( void );
+        void                    hide_after( void );
+        void                    toggle_comments( void );
+
 		void					handle_login( void );
 		void					handle_textview_changed( void );
 		void					handle_entry_tag_changed( void );
@@ -74,6 +80,7 @@ class EntryView : public Entry::Shower
 
 		// WIDGETS
 		Gtk::VBox				*m_vbox_entry;
+		Gtk::Button             *m_button_print;
 		Gtk::ToggleButton		*m_button_toggle_favorite;
 		Gtk::Button				*m_button_dismiss;
 		Gtk::Button				*m_button_reset_theme;
@@ -86,6 +93,7 @@ class EntryView : public Entry::Shower
 		Gtk::EventBox			*m_eventbox_highlight;		// necessary to change bg color!!
 		Gtk::Button				*m_button_add_bullet;
 		Gtk::Button				*m_button_add_checkbox;
+        Gtk::ToggleButton       *m_button_toggle_comments;
 
 		TextviewDiary			*m_textviewdiary;
 		TagWidget				*m_tag_widget;
