@@ -85,8 +85,10 @@ TagView::handle_filter_toggled( void )
 		return;
 
 	Diary::d->set_filter_tag( m_button_filter->get_active() ? m_ptr2tag : NULL );
-	Lifeobase::base->update_filter_tag();
-	Lifeobase::base->update_tag_icon( m_ptr2tag );
+    Lifeobase::base->update_button_filter_tag();
+    Lifeobase::base->update_button_remove_filters();
+    Lifeobase::base->update_tag_icon( m_ptr2tag );
+    Lifeobase::base->update_entry_list();
 }
 
 void
@@ -220,6 +222,8 @@ TagView::show( Tag &tag )
 		 iter != tag.m_items.rend(); ++iter )
 	{
 		Entry *entry = dynamic_cast< Entry* >( *iter );
+        if( entry->get_date().is_ordinal() )
+            continue;
 		const Date ym_entry( entry->get_date().get_yearmonth() );
 		if( yearmonth_last == 0 )
 			yearmonth_last = ym_entry;
@@ -261,7 +265,8 @@ TagView::dismiss_tag( void )
 	if( Diary::d->get_filter_tag() == m_ptr2tag )
 	{
 		Diary::d->set_filter_tag( NULL );
-		Lifeobase::base->update_filter_tag();
+        Lifeobase::base->update_button_remove_filters();
+        Lifeobase::base->update_entry_list();
 	}
 	Diary::d->dismiss_tag( m_ptr2tag );
 	Lifeobase::base->update_tag_list();
@@ -277,7 +282,7 @@ TagView::is_row_separator( const Glib::RefPtr< Gtk::TreeModel > &model,
 	return ( row[ colrec_category.type ] == TCT_SEPARATOR );
 }
 
-// TAG CATEGORY ================================================================
+// TAG CATEGORY ====================================================================================
 CategoryTagsView::CategoryTagsView( void )
 {
 	CategoryTags::shower = this;
@@ -349,7 +354,7 @@ CategoryTagsView::handle_name_applied( void )
 void
 CategoryTagsView::dismiss_category( void )
 {
-	if( Lifeobase::base->confirm_dismiss_element() )
+	if( ! Lifeobase::base->confirm_dismiss_element() )
 		return;
 
 	Lifeobase::base->remove_element_from_history( m_ptr2category );
@@ -361,7 +366,7 @@ CategoryTagsView::dismiss_category( void )
 	Lifeobase::base->update_tag_categories();
 }
 
-// CHAPTER =====================================================================
+// CHAPTER =========================================================================================
 ChapterView::ChapterView( void )
 {
 	Chapter::shower = this;
@@ -557,7 +562,7 @@ ChapterView::show( Chapter &chapter )
 	m_frame_actions->set_visible( ! flag_temporal );
 }
 
-// THEME =======================================================================
+// THEME ===========================================================================================
 ThemeView::ThemeView( void )
 {
 	Theme::shower = this;
@@ -574,6 +579,8 @@ ThemeView::ThemeView( void )
 		Lifeobase::builder->get_widget( "colorbutton_theme_heading", m_colorbutton_heading );
 		Lifeobase::builder->get_widget( "colorbutton_theme_subheading", m_colorbutton_subheading );
 		Lifeobase::builder->get_widget( "colorbutton_theme_highlight", m_colorbutton_highlight );
+		Lifeobase::builder->get_widget( "eventbox_theme_preview", m_eventbox_preview );
+		Lifeobase::builder->get_widget( "label_theme_preview", m_label_preview );
 		Lifeobase::builder->get_widget( "button_theme_duplicate", m_button_duplicate );
 		Lifeobase::builder->get_widget( "button_theme_dismiss", m_button_dismiss );
 		Lifeobase::builder->get_widget( "button_theme_default", m_button_make_default );
@@ -635,6 +642,7 @@ ThemeView::show( Theme &theme )
 	m_colorbutton_subheading->set_color( theme.color_subheading );
 	m_colorbutton_highlight->set_color( theme.color_highlight );
 
+	update_preview();
 	m_vbox->set_sensitive( ! theme.is_system() );
 	m_button_dismiss->set_sensitive( ! theme.is_system() );
 	m_button_make_default->set_visible( &theme != Diary::d->get_default_theme() );
@@ -663,6 +671,7 @@ void
 ThemeView::handle_font_changed( void )
 {
 	m_ptr2theme->font = Pango::FontDescription( m_fontbutton->get_font_name() );
+	update_preview();
 }
 
 void
@@ -673,13 +682,32 @@ ThemeView::handle_color_changed( void )
 	m_ptr2theme->color_heading = m_colorbutton_heading->get_color();
 	m_ptr2theme->color_subheading = m_colorbutton_subheading->get_color();
 	m_ptr2theme->color_highlight = m_colorbutton_highlight->get_color();
+	update_preview();
+}
+
+void
+ThemeView::update_preview( void )
+{
+    Glib::ustring str_preview( Glib::ustring::compose(
+            "<span color='%1' size='xx-large' weight='bold'>Heading</span>\n"
+            " <span color='%2'size='larger' weight='bold'>Subheading</span>\n"
+            "Body text <span bgcolor='%3'>highlighted text</span>",
+            convert_gdkcolor_to_html( m_ptr2theme->color_heading ),
+            convert_gdkcolor_to_html( m_ptr2theme->color_subheading ),
+            convert_gdkcolor_to_html( m_ptr2theme->color_highlight ) ) );
+    m_label_preview->set_markup( str_preview );
+    m_label_preview->modify_fg( Gtk::STATE_NORMAL, m_ptr2theme->color_text );
+    m_label_preview->modify_fg( Gtk::STATE_INSENSITIVE, m_ptr2theme->color_text );
+    m_eventbox_preview->modify_bg( Gtk::STATE_NORMAL, m_ptr2theme->color_base );
+    m_eventbox_preview->modify_bg( Gtk::STATE_INSENSITIVE, m_ptr2theme->color_base );
+    m_label_preview->modify_font( m_ptr2theme->font );
 }
 
 // creating new themes is done by duplicating existing ones
 void
 ThemeView::duplicate( void )
 {
-	Theme *new_theme = Diary::d->duplicate_theme( *m_ptr2theme );
+	Theme *new_theme = Diary::d->duplicate_theme( m_ptr2theme );
 	Lifeobase::base->update_theme_list();
 	new_theme->show();
 }
@@ -706,16 +734,16 @@ ThemeView::dismiss_theme( void )
 	Lifeobase::base->update_theme_list();
 }
 
-// DIARY =======================================================================
+// DIARY ===========================================================================================
 DiaryView::DiaryView( void )
-	:	m_vbox_diary( NULL ), m_dialog_password( NULL ), m_dialog_import( NULL )
+:	m_vbox_diary( NULL ), m_dialog_password( NULL ), m_dialog_import( NULL ), m_dialog_export( NULL )
 {
 	Diary::shower = this;
 	m_ptr2diary = Diary::d;	// for now no other diary is shown in the view
 
 	Gtk::Button *button_import( NULL );
 	Gtk::Button *button_export( NULL );
-	Gtk::Button *button_add_topic( NULL );
+	Gtk::HBox   *hbox_chapter_ctg( NULL );
 	try
 	{
 		Lifeobase::builder->get_widget( "vbox_diary", m_vbox_diary );
@@ -728,14 +756,16 @@ DiaryView::DiaryView( void )
 		Lifeobase::builder->get_widget( "label_startup_elem_drop", m_label_startup_elem_drop );
 		Lifeobase::builder->get_widget( "button_startup_elem_go", m_button_startup_elem_go );
 
-		Lifeobase::builder->get_widget( "combobox_chapter_ctg",
-				m_combobox_chapter_ctg );
+//		Lifeobase::builder->get_widget( "combobox_chapter_ctg",
+//				m_combobox_chapter_ctg );
+		Lifeobase::builder->get_widget( "hbox_cur_chapter_ctg",
+		        hbox_chapter_ctg );
 		Lifeobase::builder->get_widget( "button_chapter_ctg_dismiss",
 				m_button_chapter_ctg_dismiss );
 		Lifeobase::builder->get_widget( "button_chapter_ctg_rename",
 				m_button_chapter_ctg_rename );
 
-		Lifeobase::builder->get_widget( "button_add_topic", button_add_topic );
+        Lifeobase::builder->get_widget_derived( "drawingarea_diary_chart", m_widgetchart );
 
 		Lifeobase::builder->get_widget( "button_import", button_import );
 		Lifeobase::builder->get_widget( "button_export", button_export );
@@ -746,6 +776,9 @@ DiaryView::DiaryView( void )
 
 		m_liststore_startup_type = Gtk::ListStore::create( colrec_startup_type );
 		m_liststore_chapter_ctg = Gtk::ListStore::create( colrec_chapter_ctg );
+
+		// temporary until we upgrade to gtkmm-3:
+		m_combobox_chapter_ctg = Gtk::manage( new Gtk::ComboBoxEntry );
 	}
 	catch( ... ) { }
 
@@ -765,6 +798,9 @@ DiaryView::DiaryView( void )
 	m_label_startup_elem_drop->drag_dest_set( Lifeobase::base->drag_targets_entry );
 
 	// CHAPTER CATEGORIES
+	hbox_chapter_ctg->pack_start( *m_combobox_chapter_ctg );
+	hbox_chapter_ctg->reorder_child( *m_combobox_chapter_ctg, 0 );
+	m_combobox_chapter_ctg->show();
 	m_combobox_chapter_ctg->set_model( m_liststore_chapter_ctg );
 	m_combobox_chapter_ctg->set_text_column( colrec_chapter_ctg.name );
 	m_combobox_chapter_ctg->set_row_separator_func(
@@ -790,9 +826,6 @@ DiaryView::DiaryView( void )
 	m_button_chapter_ctg_dismiss->signal_clicked().connect(
 			sigc::mem_fun( this, &DiaryView::dismiss_cur_chapter_ctg ) );
 
-	button_add_topic->signal_clicked().connect(
-			sigc::mem_fun( this, &DiaryView::add_topic ) );
-
 	button_import->signal_clicked().connect(
 			sigc::mem_fun( *this, &DiaryView::start_dialog_import ) );
 	button_export->signal_clicked().connect(
@@ -807,24 +840,6 @@ DiaryView::~DiaryView( void )
 	Diary::shower = NULL;
 }
 
-/*Gtk::Frame*
-add_group( const Glib::ustring& str_label, Gtk::Widget& content )
-{
-	Gtk::Frame *frame = Gtk::manage( new Gtk::Frame );
-	Gtk::Label *label = Gtk::manage( new Gtk::Label );
-
-	Gtk::Alignment *alignment = Gtk::manage(
-			new Gtk::Alignment( .5, .5, .5, .5 ) );
-
-	label->set_markup( str_label );
-	frame->set_shadow_type( Gtk::SHADOW_NONE );
-	frame->set_label_widget( *label );
-	alignment->add( content );
-	frame->add( *alignment );
-
-	return frame;
-}*/
-
 void
 DiaryView::handle_login( void )
 {
@@ -881,6 +896,42 @@ DiaryView::show( Diary &diary )
 	m_label_encryption->set_label( diary.m_passphrase.empty() ? _( "Unencrypted" ) :
 												_( "Encrypted" ) );
 
+    // CHART DATA
+    ChartPoints *points( new ChartPoints );
+    Date yearmonth_last( 0 );
+    int value( 0 );
+    for( PoolEntries::reverse_iterator iter = diary.m_entries.rbegin();
+         iter != diary.m_entries.rend(); ++iter )
+    {
+        Entry *entry( iter->second );
+        if( entry->get_date().is_ordinal() )
+            continue;
+        const Date ym_entry( entry->get_date().get_yearmonth() );
+        if( yearmonth_last == 0 )
+            yearmonth_last = ym_entry;
+        else
+        if( yearmonth_last != ym_entry )
+        {
+            points->add( yearmonth_last, value );
+
+            // fill empty months
+            for( Date ym_zero = yearmonth_last; ; )
+            {
+                ym_zero.forward_month();
+                if( ym_zero >= ym_entry )
+                    break;
+                points->add( ym_zero, 0 );
+            }
+
+            yearmonth_last = ym_entry;
+            value = 0;
+        }
+        value++;
+    }
+    points->add( yearmonth_last, value );
+
+    m_widgetchart->set_points( points );
+
 #if GTK_CHECK_VERSION(2,18,0)
 	m_label_path->set_markup( Glib::ustring::compose( "<a href=\"file://%1\">%2</a>",
 			Glib::path_get_dirname( diary.m_path ), diary.m_path ) );
@@ -926,29 +977,28 @@ DiaryView::start_dialog_password( void )
 void
 DiaryView::start_dialog_import( void )
 {
-	if( m_dialog_import == NULL )
-	{
-		Lifeobase::builder->get_widget_derived( "dialog_import", m_dialog_import );
-	}
+    if( m_dialog_import == NULL )
+        Lifeobase::builder->get_widget_derived( "dialog_import", m_dialog_import );
 
-	int response = m_dialog_import->run();
-	m_dialog_import->hide();
+    int response = m_dialog_import->run();
+    m_dialog_import->hide();
 
-	if( response == RESPONSE_GO )
-	{
-		Lifeobase::base->update_entry_list();
-		Lifeobase::base->update_tag_list();
-		//Lifeobase::base->update_theme_list();
-	}
+    if( response == RESPONSE_GO )
+    {
+        Lifeobase::base->update_entry_list();
+        Lifeobase::base->update_tag_list();
+        Lifeobase::base->update_theme_list();
+    }
 }
 
 void
 DiaryView::start_dialog_export( void )
 {
-	DialogExport *dialog_export = new DialogExport( m_ptr2diary );
-	dialog_export->run();
+    if( m_dialog_export == NULL )
+        Lifeobase::builder->get_widget_derived( "dialog_export", m_dialog_export );
 
-	delete dialog_export;
+    m_dialog_export->run();
+    m_dialog_export->hide();
 }
 
 //void
@@ -1125,11 +1175,3 @@ DiaryView::is_row_separator( const Glib::RefPtr< Gtk::TreeModel > &model,
 	Gtk::TreeRow row = * iter;
 	return ( row[ colrec_chapter_ctg.type ] == CCCT_SEPARATOR );
 }
-
-void
-DiaryView::add_topic( void )
-{
-	Diary::d->add_topic( _( "New topic" ) );
-	Lifeobase::base->update_entry_list();
-	// show the new topic?
-}
