@@ -30,11 +30,11 @@ using namespace LIFEO;
 
 
 ChartPoint::ChartPoint( Date date_0, int value_0 )
-	:	date( date_0 ), value( value_0 )
+:   date( date_0 ), value( value_0 )
 {}
 
 ChartPoints::ChartPoints( void )
-	:	value_min( -1 ), value_max( -1 ), flag_use_current( false )
+:   value_min( -1 ), value_max( -1 ), flag_use_current( false )
 {
 }
 
@@ -101,7 +101,8 @@ WidgetChart::update_col_geom( bool flag_first_time )
 
 		step_x = m_col_count == 1 ? length : length / ( m_col_count - 1 );
 
-		m_overview_height = m_col_count < m_points->size() ? OVERVIEW_HEIGHT : 0.0;
+        m_overview_height = m_col_count < m_points->size() ?
+                log10( m_height ) * OVERVIEW_COEFFICIENT : 0.0;
 		y_max = m_height - 2 * bar_height - m_overview_height;
 		y_mid = ( y_max + y_min ) / 2;
 		amplitude = y_max - y_min;
@@ -250,27 +251,23 @@ WidgetChart::on_expose_event( GdkEventExpose *event )
 		// FONT FACE
 		cr->set_font_face( m_font_main );
 
-		// HANDLE THERE-IS-TOO-FEW-ENTRIES-CASE SPECIALLY
-		if( m_points->size() < 2 )
-		{
-			// FIXME: do this more elegantly
-			cr->rectangle( 0.0, 0.0, m_width, m_height );
-			cr->set_source_rgb( 0.8, 0.8, 0.8 );
-			cr->fill();
-			cr->set_font_size( 1.5 * label_height );
-			cr->set_source_rgb( 0.0, 0.0, 0.0 );
-			Cairo::TextExtents te;
-			cr->get_text_extents( "NOT ENOUGH DATA", te );
-			cr->move_to( ( m_width - te.width ) / 2 , m_height / 2 );
-			cr->show_text( "NOT ENOUGH DATA" );
-			return true;
-		}
-
 		// BACKGROUND
 		cr->rectangle( 0.0, 0.0, m_width, y_max );
 		cr->set_source_rgba( 1.0, 1.0, 1.0, 0.6 );
 		cr->fill();
 
+        // HANDLE THERE-IS-TOO-FEW-ENTRIES-CASE SPECIALLY
+        if( m_points->size() < 2 )
+        {
+            cr->set_font_size( 1.5 * label_height );
+            cr->set_source_rgb( 0.0, 0.0, 0.0 );
+            Cairo::TextExtents te;
+            cr->get_text_extents( _( "INSUFFICIENT DATA" ), te );
+            cr->move_to( ( m_width - te.width ) / 2 , m_height / 2 );
+            cr->show_text( _( "INSUFFICIENT DATA" ) );
+            return true;
+        }
+
 		// END REGIONS
 		if( m_col_start == 0 )
 		{
