@@ -88,6 +88,88 @@ WidgetEntryList::expand_element( const DiaryElement *element )
 	expand_to_path( path );
 }
 
+void
+WidgetEntryList::go_up( bool flag_entry_operation )
+{
+    DiaryElement *elem( Lifeobase::base->get_cur_elem() );
+
+    if( elem == NULL )
+        return;
+    else
+    if( elem->get_type() < DiaryElement::IT_DIARY ) // not list element
+        return;
+
+    Gtk::TreePath path( m_treemodelsort_entries->convert_child_path_to_path(
+                elem->m_list_data->treepath ) );
+
+    do
+    {
+        if( ! path.prev() )
+        {
+            if( path.size() > 1 )
+                path.up();
+            else    // diary
+            if( make_path_deeper_last( path ) )
+                make_path_deeper_last( path ); // go still deeper if possible:
+        }
+        else
+            make_path_deeper_last( path );
+
+        elem = ( * m_treemodelsort_entries->get_iter( path ) )[ ListData::colrec->ptr ];
+    }
+    // repeat until an entry is found if that is what we are looking for
+    // BEWARE: do not set this flag when there is no entry in the list
+    while( flag_entry_operation && elem->get_type() != DiaryElement::IT_ENTRY );
+
+    PRINT_DEBUG( "previous path: " + path.to_string() );
+
+    Gtk::TreeRow row( * m_treemodelsort_entries->get_iter( path ) );
+    DiaryElement *element( row[ ListData::colrec->ptr ] );
+    element->show();
+}
+
+void
+WidgetEntryList::go_down( bool flag_entry_operation )
+{
+    DiaryElement *elem( Lifeobase::base->get_cur_elem() );
+
+    if( elem == NULL )
+        return;
+    else
+    if( elem->get_type() < DiaryElement::IT_DIARY ) // not list element
+        return;
+
+    Gtk::TreePath path( m_treemodelsort_entries->convert_child_path_to_path(
+                elem->m_list_data->treepath ) );
+
+    do
+    {
+        if( ! m_treemodelsort_entries->get_iter( path )->children().empty() )
+            path.down();
+        else
+        if( ! move_path_next( path ) )
+        {
+            while( path.size() > 1 )
+            {
+                path.up();
+                if( move_path_next( path ) )
+                    break;
+            }
+        }
+
+        elem = ( * m_treemodelsort_entries->get_iter( path ) )[ ListData::colrec->ptr ];
+    }
+    // repeat until an entry is found if that is what we are looking for
+    // BEWARE: do not set this flag when there is no entry in the list
+    while( flag_entry_operation && elem->get_type() != DiaryElement::IT_ENTRY );
+
+    PRINT_DEBUG( "next path: " + path.to_string() );
+
+    Gtk::TreeRow row( * m_treemodelsort_entries->get_iter( path ) );
+    DiaryElement *listitem = row[ ListData::colrec->ptr ];
+    listitem->show();
+}
+
 void
 WidgetEntryList::handle_sorting_criteria_changed( SortingCriteria sc )
 {
@@ -252,6 +334,29 @@ WidgetEntryList::on_button_release_event( GdkEventButton *event )
 	return Gtk::TreeView::on_button_release_event( event );
 }
 
+bool
+WidgetEntryList::on_key_press_event( GdkEventKey *event )
+{
+    if( event->state == 0 )
+    {
+        switch( event->keyval )
+        {
+            case GDK_Home:
+                Diary::d->show();
+                return true;
+            case GDK_End:
+                return true;
+            case GDK_Up:
+                go_up( false );
+                return true;
+            case GDK_Down:
+                go_down( false );
+                return true;
+        }
+    }
+    return Gtk::TreeView::on_key_press_event( event );
+}
+
 void
 WidgetEntryList::on_drag_begin( const Glib::RefPtr< Gdk::DragContext >& )
 {
@@ -469,3 +574,26 @@ WidgetEntryList::sort_by_size( const Gtk::TreeModel::iterator &itr1,
 		return 0;
 }
 
+inline bool
+WidgetEntryList::move_path_next( Gtk::TreePath &path )
+{
+    if( unsigned( path.back() ) < ( m_treemodelsort_entries->
+                get_iter( path )->parent()->children().size() - 1 ) )
+    {
+        path.next();
+        return true;
+    }
+    else
+        return false;
+}
+
+inline bool
+WidgetEntryList::make_path_deeper_last( Gtk::TreePath &path )
+{
+    if( ! m_treemodelsort_entries->get_iter( path )->children().empty() )
+    {
+        path.push_back( m_treemodelsort_entries->get_iter( path )->children().size() - 1 );
+        return true;
+    }
+    return false;
+}
